import typing

from vkbottle_types.methods.base_category import BaseCategory
from vkbottle_types.objects import (
    AddressFields,
    BaseUserGroupFields,
    GroupsAddress,
    GroupsCallbackSettings,
    GroupsFields,
    GroupsFilter,
    GroupsGroupFull,
    GroupsGroupTag,
    GroupsLinksItem,
    GroupsLongPollServer,
    GroupsLongPollSettings,
    GroupsMemberStatus,
    GroupsMemberStatusFull,
    UsersFields,
)
from vkbottle_types.responses.base import (
    BaseBoolResponse,
    BaseOkResponse,
    BaseOkResponseModel,
)
from vkbottle_types.responses.groups import *  # noqa: F401,F403  # type: ignore


class GroupsCategory(BaseCategory):
    async def add_address(
        self,
        address: str,
        city_id: int,
        group_id: int,
        latitude: float,
        longitude: float,
        title: str,
        additional_address: str | None = None,
        is_main_address: bool | None = None,
        metro_id: int | None = None,
        phone: str | None = None,
        timetable: str | None = None,
        work_info_status: str | None = None,
        **kwargs: typing.Any,
    ) -> "GroupsAddress":
        """Method `groups.addAddress()`

        :param address:
        :param city_id:
        :param group_id:
        :param latitude:
        :param longitude:
        :param title:
        :param additional_address:
        :param is_main_address:
        :param metro_id:
        :param phone:
        :param timetable:
        :param work_info_status:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("groups.addAddress", params)
        model = GroupsAddAddressResponse
        return model(**response).response

    async def add_callback_server(
        self,
        group_id: int,
        title: str,
        url: str,
        secret_key: str | None = None,
        **kwargs: typing.Any,
    ) -> GroupsAddCallbackServerResponseModel:
        """Method `groups.addCallbackServer()`

        :param group_id:
        :param title:
        :param url:
        :param secret_key:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("groups.addCallbackServer", params)
        model = GroupsAddCallbackServerResponse
        return model(**response).response

    async def add_link(
        self,
        group_id: int,
        link: str,
        text: str | None = None,
        **kwargs: typing.Any,
    ) -> "GroupsLinksItem":
        """Method `groups.addLink()`

        :param group_id: Community ID.
        :param link: Link URL.
        :param text: Description text for the link.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("groups.addLink", params)
        model = GroupsAddLinkResponse
        return model(**response).response

    async def approve_request(
        self,
        group_id: int,
        user_id: int,
        **kwargs: typing.Any,
    ) -> BaseOkResponseModel:
        """Method `groups.approveRequest()`

        :param group_id: Community ID.
        :param user_id: User ID.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("groups.approveRequest", params)
        model = BaseOkResponse
        return model(**response).response

    async def ban(
        self,
        group_id: int,
        comment: str | None = None,
        comment_visible: bool | None = None,
        end_date: int | None = None,
        owner_id: int | None = None,
        reason: int | None = None,
        **kwargs: typing.Any,
    ) -> BaseOkResponseModel:
        """Method `groups.ban()`

        :param group_id:
        :param comment:
        :param comment_visible:
        :param end_date:
        :param owner_id:
        :param reason:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("groups.ban", params)
        model = BaseOkResponse
        return model(**response).response

    async def create(
        self,
        title: str,
        description: str | None = None,
        public_category: int | None = None,
        public_subcategory: int | None = None,
        subtype: int | None = None,
        type: str | None = None,
        **kwargs: typing.Any,
    ) -> "GroupsGroupFull":
        """Method `groups.create()`

        :param title: Community title.
        :param description: Community description (ignored for 'type' = 'public').
        :param public_category: Category ID (for 'type' = 'public' only).
        :param public_subcategory: Public page subcategory ID.
        :param subtype: Public page subtype. Possible values: *'1' - place or small business,, *'2' - company, organization or website,, *'3' - famous person or group of people,, *'4' - product or work of art.
        :param type: Community type. Possible values: *'group' - group,, *'event' - event,, *'public' - public page
        """

        params = self.get_set_params(locals())
        response = await self.api.request("groups.create", params)
        model = GroupsCreateResponse
        return model(**response).response

    async def delete_address(
        self,
        address_id: int,
        group_id: int,
        **kwargs: typing.Any,
    ) -> BaseOkResponseModel:
        """Method `groups.deleteAddress()`

        :param address_id:
        :param group_id:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("groups.deleteAddress", params)
        model = BaseOkResponse
        return model(**response).response

    async def delete_callback_server(
        self,
        group_id: int,
        server_id: int,
        **kwargs: typing.Any,
    ) -> BaseOkResponseModel:
        """Method `groups.deleteCallbackServer()`

        :param group_id:
        :param server_id:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("groups.deleteCallbackServer", params)
        model = BaseOkResponse
        return model(**response).response

    async def delete_link(
        self,
        group_id: int,
        link_id: int,
        **kwargs: typing.Any,
    ) -> BaseOkResponseModel:
        """Method `groups.deleteLink()`

        :param group_id: Community ID.
        :param link_id: Link ID.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("groups.deleteLink", params)
        model = BaseOkResponse
        return model(**response).response

    async def disable_online(
        self,
        group_id: int,
        **kwargs: typing.Any,
    ) -> BaseOkResponseModel:
        """Method `groups.disableOnline()`

        :param group_id:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("groups.disableOnline", params)
        model = BaseOkResponse
        return model(**response).response

    async def edit(
        self,
        group_id: int,
        access: int | None = None,
        addresses: bool | None = None,
        age_limits: int | None = None,
        articles: bool | None = None,
        audio: int | None = None,
        city: int | None = None,
        contacts: bool | None = None,
        country: int | None = None,
        description: str | None = None,
        disable_replies_from_groups: bool | None = None,
        docs: int | None = None,
        email: str | None = None,
        event_finish_date: int | None = None,
        event_group_id: int | None = None,
        event_start_date: int | None = None,
        events: bool | None = None,
        links: bool | None = None,
        main_section: int | None = None,
        market: bool | None = None,
        market_buttons: str | None = None,
        market_city: list[int] | None = None,
        market_comments: bool | None = None,
        market_contact: int | None = None,
        market_country: list[int] | None = None,
        market_currency: int | None = None,
        market_wiki: int | None = None,
        messages: bool | None = None,
        obscene_filter: bool | None = None,
        obscene_stopwords: bool | None = None,
        obscene_words: list[str] | None = None,
        phone: str | None = None,
        photos: int | None = None,
        places: bool | None = None,
        public_category: int | None = None,
        public_date: str | None = None,
        public_subcategory: int | None = None,
        rss: str | None = None,
        screen_name: str | None = None,
        secondary_section: int | None = None,
        subject: int | None = None,
        title: str | None = None,
        topics: int | None = None,
        toxic_filter: bool | None = None,
        video: int | None = None,
        wall: int | None = None,
        website: str | None = None,
        wiki: int | None = None,
        **kwargs: typing.Any,
    ) -> BaseOkResponseModel:
        """Method `groups.edit()`

        :param group_id: Community ID.
        :param access: Community type. Possible values: *'0' - open,, *'1' - closed,, *'2' - private.
        :param addresses:
        :param age_limits: Community age limits. Possible values: *'1' - no limits,, *'2' - 16+,, *'3' - 18+.
        :param articles:
        :param audio: Audio settings. Possible values: *'0' - disabled,, *'1' - open,, *'2' - limited (for groups and events only).
        :param city: City of the community.
        :param contacts: Contacts settings (for public pages only). Possible values: *'0' - disabled,, *'1' - enabled.
        :param country: Country of the community.
        :param description: Community description.
        :param disable_replies_from_groups:
        :param docs: Documents settings. Possible values: *'0' - disabled,, *'1' - open,, *'2' - limited (for groups and events only).
        :param email: Organizer email (for events).
        :param event_finish_date: Event finish date in Unixtime format.
        :param event_group_id: Organizer community ID (for events only).
        :param event_start_date: Event start date in Unixtime format.
        :param events: Events settings (for public pages only). Possible values: *'0' - disabled,, *'1' - enabled.
        :param links: Links settings (for public pages only). Possible values: *'0' - disabled,, *'1' - enabled.
        :param main_section:
        :param market: Market settings. Possible values: *'0' - disabled,, *'1' - enabled.
        :param market_buttons: Buttons details, see market/objects.json#/definitions/market_custom_button
        :param market_city: Market delivery cities (if only one country is specified).
        :param market_comments: market comments settings. Possible values: *'0' - disabled,, *'1' - enabled.
        :param market_contact: Seller contact for market. Set '0' for community messages.
        :param market_country: Market delivery countries.
        :param market_currency: Market currency settings. Possbile values: , *'643' - Russian rubles,, *'980' - Ukrainian hryvnia,, *'398' - Kazakh tenge,, *'978' - Euro,, *'840' - US dollars
        :param market_wiki: ID of a wiki page with market description.
        :param messages: Community messages. Possible values: *'0' - disabled,, *'1' - enabled.
        :param obscene_filter: Obscene expressions filter in comments. Possible values: , *'0' - disabled,, *'1' - enabled.
        :param obscene_stopwords: Stopwords filter in comments. Possible values: , *'0' - disabled,, *'1' - enabled.
        :param obscene_words: Keywords for stopwords filter.
        :param phone: Organizer phone number (for events).
        :param photos: Photos settings. Possible values: *'0' - disabled,, *'1' - open,, *'2' - limited (for groups and events only).
        :param places: Places settings (for public pages only). Possible values: *'0' - disabled,, *'1' - enabled.
        :param public_category: Public page category ID.
        :param public_date: Founding date of a company or organization owning the community in "dd.mm.YYYY" format.
        :param public_subcategory: Public page subcategory ID.
        :param rss: RSS feed address for import (available only to communities with special permission. Contact vk.com/support to get it.
        :param screen_name: Community screen name.
        :param secondary_section:
        :param subject: Community subject. Possible values: , *'1' - auto/moto,, *'2' - activity holidays,, *'3' - business,, *'4' - pets,, *'5' - health,, *'6' - dating and communication, , *'7' - games,, *'8' - IT (computers and software),, *'9' - cinema,, *'10' - beauty and fashion,, *'11' - cooking,, *'12' - art and culture,, *'13' - literature,, *'14' - mobile services and internet,, *'15' - music,, *'16' - science and technology,, *'17' - real estate,, *'18' - news and media,, *'19' - security,, *'20' - education,, *'21' - home and renovations,, *'22' - politics,, *'23' - food,, *'24' - industry,, *'25' - travel,, *'26' - work,, *'27' - entertainment,, *'28' - religion,, *'29' - family,, *'30' - sports,, *'31' - insurance,, *'32' - television,, *'33' - goods and services,, *'34' - hobbies,, *'35' - finance,, *'36' - photo,, *'37' - esoterics,, *'38' - electronics and appliances,, *'39' - erotic,, *'40' - humor,, *'41' - society, humanities,, *'42' - design and graphics.
        :param title: Community title.
        :param topics: Board topics settings. Possbile values: , *'0' - disabled,, *'1' - open,, *'2' - limited (for groups and events only).
        :param toxic_filter:
        :param video: Video settings. Possible values: *'0' - disabled,, *'1' - open,, *'2' - limited (for groups and events only).
        :param wall: Wall settings. Possible values: *'0' - disabled,, *'1' - open,, *'2' - limited (groups and events only),, *'3' - closed (groups and events only).
        :param website: Website that will be displayed in the community information field.
        :param wiki: Wiki pages settings. Possible values: *'0' - disabled,, *'1' - open,, *'2' - limited (for groups and events only).
        """

        params = self.get_set_params(locals())
        response = await self.api.request("groups.edit", params)
        model = BaseOkResponse
        return model(**response).response

    async def edit_address(
        self,
        address_id: int,
        group_id: int,
        additional_address: str | None = None,
        address: str | None = None,
        city_id: int | None = None,
        is_main_address: bool | None = None,
        latitude: float | None = None,
        longitude: float | None = None,
        metro_id: int | None = None,
        phone: str | None = None,
        timetable: str | None = None,
        title: str | None = None,
        work_info_status: str | None = None,
        **kwargs: typing.Any,
    ) -> "GroupsAddress":
        """Method `groups.editAddress()`

        :param address_id:
        :param group_id:
        :param additional_address:
        :param address:
        :param city_id:
        :param is_main_address:
        :param latitude:
        :param longitude:
        :param metro_id:
        :param phone:
        :param timetable:
        :param title:
        :param work_info_status:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("groups.editAddress", params)
        model = GroupsEditAddressResponse
        return model(**response).response

    async def edit_callback_server(
        self,
        group_id: int,
        server_id: int,
        title: str,
        url: str,
        secret_key: str | None = None,
        **kwargs: typing.Any,
    ) -> BaseOkResponseModel:
        """Method `groups.editCallbackServer()`

        :param group_id:
        :param server_id:
        :param title:
        :param url:
        :param secret_key:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("groups.editCallbackServer", params)
        model = BaseOkResponse
        return model(**response).response

    async def edit_link(
        self,
        group_id: int,
        link_id: int,
        text: str | None = None,
        **kwargs: typing.Any,
    ) -> BaseOkResponseModel:
        """Method `groups.editLink()`

        :param group_id: Community ID.
        :param link_id: Link ID.
        :param text: New description text for the link.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("groups.editLink", params)
        model = BaseOkResponse
        return model(**response).response

    async def edit_manager(
        self,
        group_id: int,
        user_id: int,
        contact_email: str | None = None,
        contact_phone: str | None = None,
        contact_position: str | None = None,
        is_call_operator: bool | None = None,
        is_contact: bool | None = None,
        role: str | None = None,
        **kwargs: typing.Any,
    ) -> BaseOkResponseModel:
        """Method `groups.editManager()`

        :param group_id: Community ID.
        :param user_id: User ID.
        :param contact_email: Contact e-mail.
        :param contact_phone: Contact phone.
        :param contact_position: Position to show in Contacts block.
        :param is_call_operator: '1' — allow the manager to accept community calls.
        :param is_contact: '1' - to show the manager in Contacts block of the community.
        :param role: Manager role. Possible values: *'moderator',, *'editor',, *'administrator',, *'advertiser'.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("groups.editManager", params)
        model = BaseOkResponse
        return model(**response).response

    async def enable_online(
        self,
        group_id: int,
        **kwargs: typing.Any,
    ) -> BaseOkResponseModel:
        """Method `groups.enableOnline()`

        :param group_id:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("groups.enableOnline", params)
        model = BaseOkResponse
        return model(**response).response

    @typing.overload
    async def get(
        self,
        extended: typing.Literal[True],
        count: int | None = None,
        fields: list[GroupsFields] | None = None,
        filter: list[GroupsFilter] | None = None,
        offset: int | None = None,
        user_id: int | None = None,
        **kwargs: typing.Any,
    ) -> GroupsGetObjectExtendedResponseModel: ...

    @typing.overload
    async def get(
        self,
        extended: typing.Literal[False] | None = None,
        count: int | None = None,
        fields: list[GroupsFields] | None = None,
        filter: list[GroupsFilter] | None = None,
        offset: int | None = None,
        user_id: int | None = None,
        **kwargs: typing.Any,
    ) -> GroupsGetResponseModel: ...

    async def get(
        self,
        extended: bool | None = None,
        count: int | None = None,
        fields: list[GroupsFields] | None = None,
        filter: list[GroupsFilter] | None = None,
        offset: int | None = None,
        user_id: int | None = None,
        **kwargs: typing.Any,
    ) -> GroupsGetObjectExtendedResponseModel | GroupsGetResponseModel:
        """Method `groups.get()`

        :param extended: '1' - to return complete information about a user's communities, '0' - to return a list of community IDs without any additional fields (default),
        :param count: Number of communities to return.
        :param fields: Profile fields to return.
        :param filter: Types of communities to return: 'admin' - to return communities administered by the user , 'editor' - to return communities where the user is an administrator or editor, 'moder' - to return communities where the user is an administrator, editor, or moderator, 'groups' - to return only groups, 'publics' - to return only public pages, 'events' - to return only events
        :param offset: Offset needed to return a specific subset of communities.
        :param user_id: User ID.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("groups.get", params)
        model = self.get_model(
            ((("extended",), GroupsGetObjectExtendedResponse),),
            default=GroupsGetResponse,
            params=params,
        )
        return model(**response).response

    async def get_addresses(
        self,
        group_id: int,
        address_ids: list[int] | None = None,
        count: int | None = None,
        fields: list[AddressFields] | None = None,
        latitude: float | None = None,
        longitude: float | None = None,
        offset: int | None = None,
        **kwargs: typing.Any,
    ) -> GroupsGetAddressesResponseModel:
        """Method `groups.getAddresses()`

        :param group_id: ID or screen name of the community.
        :param address_ids:
        :param count: Number of community addresses to return.
        :param fields: Address fields
        :param latitude: Latitude of  the user geo position.
        :param longitude: Longitude of the user geo position.
        :param offset: Offset needed to return a specific subset of community addresses.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("groups.getAddresses", params)
        model = GroupsGetAddressesResponse
        return model(**response).response

    async def get_banned(
        self,
        group_id: int,
        count: int | None = None,
        fields: list[BaseUserGroupFields] | None = None,
        offset: int | None = None,
        owner_id: int | None = None,
        **kwargs: typing.Any,
    ) -> GroupsGetBannedResponseModel:
        """Method `groups.getBanned()`

        :param group_id: Community ID.
        :param count: Number of users to return.
        :param fields:
        :param offset: Offset needed to return a specific subset of users.
        :param owner_id:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("groups.getBanned", params)
        model = GroupsGetBannedResponse
        return model(**response).response

    async def get_by_id(
        self,
        fields: list[GroupsFields] | None = None,
        group_id: int | str | None = None,
        group_ids: list[int | str] | None = None,
        **kwargs: typing.Any,
    ) -> GroupsGetByIdObjectResponseModel:
        """Method `groups.getById()`

        :param fields: Group fields to return.
        :param group_id: ID or screen name of the community.
        :param group_ids: IDs or screen names of communities.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("groups.getById", params)
        model = GroupsGetByIdObjectResponse
        return model(**response).response

    async def get_callback_confirmation_code(
        self,
        group_id: int,
        **kwargs: typing.Any,
    ) -> GroupsGetCallbackConfirmationCodeResponseModel:
        """Method `groups.getCallbackConfirmationCode()`

        :param group_id: Community ID.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("groups.getCallbackConfirmationCode", params)
        model = GroupsGetCallbackConfirmationCodeResponse
        return model(**response).response

    async def get_callback_servers(
        self,
        group_id: int,
        server_ids: list[int] | None = None,
        **kwargs: typing.Any,
    ) -> GroupsGetCallbackServersResponseModel:
        """Method `groups.getCallbackServers()`

        :param group_id:
        :param server_ids:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("groups.getCallbackServers", params)
        model = GroupsGetCallbackServersResponse
        return model(**response).response

    async def get_callback_settings(
        self,
        group_id: int,
        server_id: int | None = None,
        **kwargs: typing.Any,
    ) -> "GroupsCallbackSettings":
        """Method `groups.getCallbackSettings()`

        :param group_id: Community ID.
        :param server_id: Server ID.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("groups.getCallbackSettings", params)
        model = GroupsGetCallbackSettingsResponse
        return model(**response).response

    @typing.overload
    async def get_catalog_info(
        self,
        extended: typing.Literal[True],
        subcategories: bool | None = None,
        **kwargs: typing.Any,
    ) -> GroupsGetCatalogInfoExtendedResponseModel: ...

    @typing.overload
    async def get_catalog_info(
        self,
        extended: typing.Literal[False] | None = None,
        subcategories: bool | None = None,
        **kwargs: typing.Any,
    ) -> GroupsGetCatalogInfoResponseModel: ...

    async def get_catalog_info(
        self,
        extended: bool | None = None,
        subcategories: bool | None = None,
        **kwargs: typing.Any,
    ) -> GroupsGetCatalogInfoExtendedResponseModel | GroupsGetCatalogInfoResponseModel:
        """Method `groups.getCatalogInfo()`

        :param extended: 1 - to return communities count and three communities for preview. By default: 0.
        :param subcategories: 1 - to return subcategories info. By default: 0.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("groups.getCatalogInfo", params)
        model = self.get_model(
            ((("extended",), GroupsGetCatalogInfoExtendedResponse),),
            default=GroupsGetCatalogInfoResponse,
            params=params,
        )
        return model(**response).response

    async def get_invited_users(
        self,
        group_id: int,
        count: int | None = None,
        fields: list[UsersFields] | None = None,
        name_case: str | None = None,
        offset: int | None = None,
        **kwargs: typing.Any,
    ) -> GroupsGetInvitedUsersResponseModel:
        """Method `groups.getInvitedUsers()`

        :param group_id: Group ID to return invited users for.
        :param count: Number of results to return.
        :param fields: List of additional fields to be returned. Available values: 'sex, bdate, city, country, photo_50, photo_100, photo_200_orig, photo_200, photo_400_orig, photo_max, photo_max_orig, online, online_mobile, lists, domain, has_mobile, contacts, connections, site, education, universities, schools, can_post, can_see_all_posts, can_see_audio, can_write_private_message, status, last_seen, common_count, relation, relatives, counters'.
        :param name_case: Case for declension of user name and surname. Possible values: *'nom' - nominative (default),, *'gen' - genitive,, *'dat' - dative,, *'acc' - accusative, , *'ins' - instrumental,, *'abl' - prepositional.
        :param offset: Offset needed to return a specific subset of results.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("groups.getInvitedUsers", params)
        model = GroupsGetInvitedUsersResponse
        return model(**response).response

    @typing.overload
    async def get_invites(
        self,
        extended: typing.Literal[True],
        count: int | None = None,
        offset: int | None = None,
        **kwargs: typing.Any,
    ) -> GroupsGetInvitesExtendedResponseModel: ...

    @typing.overload
    async def get_invites(
        self,
        extended: typing.Literal[False] | None = None,
        count: int | None = None,
        offset: int | None = None,
        **kwargs: typing.Any,
    ) -> GroupsGetInvitesResponseModel: ...

    async def get_invites(
        self,
        extended: bool | None = None,
        count: int | None = None,
        offset: int | None = None,
        **kwargs: typing.Any,
    ) -> GroupsGetInvitesResponseModel | GroupsGetInvitesExtendedResponseModel:
        """Method `groups.getInvites()`

        :param extended: '1' - to return additional [vk.com/dev/fields_groups|fields] for communities..
        :param count: Number of invitations to return.
        :param offset: Offset needed to return a specific subset of invitations.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("groups.getInvites", params)
        model = self.get_model(
            ((("extended",), GroupsGetInvitesExtendedResponse),),
            default=GroupsGetInvitesResponse,
            params=params,
        )
        return model(**response).response

    async def get_long_poll_server(
        self,
        group_id: int,
        **kwargs: typing.Any,
    ) -> "GroupsLongPollServer":
        """Method `groups.getLongPollServer()`

        :param group_id: Community ID.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("groups.getLongPollServer", params)
        model = GroupsGetLongPollServerResponse
        return model(**response).response

    async def get_long_poll_settings(
        self,
        group_id: int,
        **kwargs: typing.Any,
    ) -> "GroupsLongPollSettings":
        """Method `groups.getLongPollSettings()`

        :param group_id: Community ID.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("groups.getLongPollSettings", params)
        model = GroupsGetLongPollSettingsResponse
        return model(**response).response

    @typing.overload
    async def get_members(
        self,
        fields: list[UsersFields],
        filter: str,
        count: int | None = None,
        group_id: int | str | None = None,
        offset: int | None = None,
        sort: str | None = None,
        **kwargs: typing.Any,
    ) -> GroupsGetMembersFieldsResponseModel: ...

    @typing.overload
    async def get_members(
        self,
        fields: list[UsersFields] | None = None,
        filter: str | None = None,
        count: int | None = None,
        group_id: int | str | None = None,
        offset: int | None = None,
        sort: str | None = None,
        **kwargs: typing.Any,
    ) -> GroupsGetMembersFilterResponseModel: ...

    @typing.overload
    async def get_members(
        self,
        fields: list[UsersFields],
        filter: str,
        count: int | None = None,
        group_id: int | str | None = None,
        offset: int | None = None,
        sort: str | None = None,
        **kwargs: typing.Any,
    ) -> GroupsGetMembersResponseModel: ...

    async def get_members(
        self,
        fields: list[UsersFields] | None = None,
        filter: str | None = None,
        count: int | None = None,
        group_id: int | str | None = None,
        offset: int | None = None,
        sort: str | None = None,
        **kwargs: typing.Any,
    ) -> GroupsGetMembersFieldsResponseModel | GroupsGetMembersFilterResponseModel | GroupsGetMembersResponseModel:
        """Method `groups.getMembers()`

        :param fields: List of additional fields to be returned. Available values: 'sex, bdate, city, country, photo_50, photo_100, photo_200_orig, photo_200, photo_400_orig, photo_max, photo_max_orig, online, online_mobile, lists, domain, has_mobile, contacts, connections, site, education, universities, schools, can_post, can_see_all_posts, can_see_audio, can_write_private_message, status, last_seen, common_count, relation, relatives, counters'.
        :param filter: *'friends' - only friends in this community will be returned,, *'unsure' - only those who pressed 'I may attend' will be returned (if it's an event).
        :param count: Number of community members to return.
        :param group_id: ID or screen name of the community.
        :param offset: Offset needed to return a specific subset of community members.
        :param sort: Sort order. Available values: 'id_asc', 'id_desc', 'time_asc', 'time_desc'. 'time_asc' and 'time_desc' are availavle only if the method is called by the group's 'moderator'.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("groups.getMembers", params)
        model = self.get_model(
            (
                (("fields",), GroupsGetMembersFieldsResponse),
                (("filter",), GroupsGetMembersFieldsResponse),
            ),
            default=GroupsGetMembersResponse,
            params=params,
        )
        return model(**response).response

    async def get_online_status(
        self,
        group_id: int,
        **kwargs: typing.Any,
    ) -> GroupsGetOnlineStatusResponseModel:
        """Method `groups.getOnlineStatus()`

        :param group_id:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("groups.getOnlineStatus", params)
        model = GroupsGetOnlineStatusResponse
        return model(**response).response

    @typing.overload
    async def get_requests(
        self,
        group_id: int,
        fields: list[UsersFields],
        count: int | None = None,
        offset: int | None = None,
        **kwargs: typing.Any,
    ) -> GroupsGetRequestsFieldsResponseModel: ...

    @typing.overload
    async def get_requests(
        self,
        group_id: int,
        fields: list[UsersFields] | None = None,
        count: int | None = None,
        offset: int | None = None,
        **kwargs: typing.Any,
    ) -> GroupsGetRequestsResponseModel: ...

    async def get_requests(
        self,
        group_id: int,
        fields: list[UsersFields] | None = None,
        count: int | None = None,
        offset: int | None = None,
        **kwargs: typing.Any,
    ) -> GroupsGetRequestsFieldsResponseModel | GroupsGetRequestsResponseModel:
        """Method `groups.getRequests()`

        :param group_id: Community ID.
        :param fields: Profile fields to return.
        :param count: Number of results to return.
        :param offset: Offset needed to return a specific subset of results.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("groups.getRequests", params)
        model = self.get_model(
            ((("fields",), GroupsGetRequestsFieldsResponse),),
            default=GroupsGetRequestsResponse,
            params=params,
        )
        return model(**response).response

    async def get_settings(
        self,
        group_id: int | str,
        **kwargs: typing.Any,
    ) -> GroupsGetSettingsResponseModel:
        """Method `groups.getSettings()`

        :param group_id: Community ID.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("groups.getSettings", params)
        model = GroupsGetSettingsResponse
        return model(**response).response

    async def get_tag_list(
        self,
        group_id: int,
        **kwargs: typing.Any,
    ) -> list[GroupsGroupTag]:
        """Method `groups.getTagList()`

        :param group_id:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("groups.getTagList", params)
        model = GroupsGetTagListResponse
        return model(**response).response

    async def get_token_permissions(
        self,
        **kwargs: typing.Any,
    ) -> GroupsGetTokenPermissionsResponseModel:
        """Method `groups.getTokenPermissions()`"""

        params = self.get_set_params(locals())
        response = await self.api.request("groups.getTokenPermissions", params)
        model = GroupsGetTokenPermissionsResponse
        return model(**response).response

    async def invite(
        self,
        group_id: int,
        user_id: int | None = None,
        user_ids_list: list[int] | None = None,
        **kwargs: typing.Any,
    ) -> BaseOkResponseModel:
        """Method `groups.invite()`

        :param group_id: Community ID.
        :param user_id: User ID.
        :param user_ids_list: User IDs.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("groups.invite", params)
        model = BaseOkResponse
        return model(**response).response

    @typing.overload
    async def is_member(
        self,
        group_id: int | str,
        extended: typing.Literal[True],
        user_ids: list[int],
        user_id: int | None = None,
        **kwargs: typing.Any,
    ) -> list[GroupsMemberStatus]: ...

    @typing.overload
    async def is_member(
        self,
        group_id: int | str,
        extended: bool | None = None,
        user_ids: list[int] | None = None,
        user_id: int | None = None,
        **kwargs: typing.Any,
    ) -> GroupsIsMemberExtendedResponseModel: ...

    @typing.overload
    async def is_member(
        self,
        group_id: int | str,
        user_ids: list[int],
        extended: bool | None = None,
        user_id: int | None = None,
        **kwargs: typing.Any,
    ) -> list[GroupsMemberStatusFull]: ...

    @typing.overload
    async def is_member(
        self,
        group_id: int | str,
        user_ids: list[int] | None = None,
        extended: bool | None = None,
        user_id: int | None = None,
        **kwargs: typing.Any,
    ) -> bool: ...

    async def is_member(
        self,
        group_id: int | str,
        user_ids: list[int] | None = None,
        extended: bool | None = None,
        user_id: int | None = None,
        **kwargs: typing.Any,
    ) -> GroupsIsMemberExtendedResponseModel | list[GroupsMemberStatusFull] | bool | list[GroupsMemberStatus]:
        """Method `groups.isMember()`

        :param group_id: ID or screen name of the community.
        :param user_ids: User IDs.
        :param extended: '1' - to return an extended response with additional fields. By default: '0'.
        :param user_id: User ID.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("groups.isMember", params)
        model = self.get_model(
            (
                (("extended",), GroupsIsMemberUserIdsResponse),
                (("user_ids",), GroupsIsMemberUserIdsResponse),
            ),
            default=BaseBoolResponse,
            params=params,
        )
        return model(**response).response

    async def join(
        self,
        group_id: int,
        not_sure: str | None = None,
        **kwargs: typing.Any,
    ) -> BaseOkResponseModel:
        """Method `groups.join()`

        :param group_id: ID or screen name of the community.
        :param not_sure: Optional parameter which is taken into account when 'gid' belongs to the event: '1' - Perhaps I will attend, '0' - I will be there for sure (default), ,
        """

        params = self.get_set_params(locals())
        response = await self.api.request("groups.join", params)
        model = BaseOkResponse
        return model(**response).response

    async def leave(
        self,
        group_id: int,
        **kwargs: typing.Any,
    ) -> BaseOkResponseModel:
        """Method `groups.leave()`

        :param group_id: ID or screen name of the community.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("groups.leave", params)
        model = BaseOkResponse
        return model(**response).response

    async def remove_user(
        self,
        group_id: int,
        user_id: int,
        **kwargs: typing.Any,
    ) -> BaseOkResponseModel:
        """Method `groups.removeUser()`

        :param group_id: Community ID.
        :param user_id: User ID.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("groups.removeUser", params)
        model = BaseOkResponse
        return model(**response).response

    async def reorder_link(
        self,
        group_id: int,
        link_id: int,
        after: int | None = None,
        **kwargs: typing.Any,
    ) -> BaseOkResponseModel:
        """Method `groups.reorderLink()`

        :param group_id: Community ID.
        :param link_id: Link ID.
        :param after: ID of the link after which to place the link with 'link_id'.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("groups.reorderLink", params)
        model = BaseOkResponse
        return model(**response).response

    async def search(
        self,
        q: str,
        city_id: int | None = None,
        count: int | None = None,
        country_id: int | None = None,
        future: bool | None = None,
        market: bool | None = None,
        offset: int | None = None,
        sort: int | None = None,
        type: str | None = None,
        **kwargs: typing.Any,
    ) -> GroupsSearchResponseModel:
        """Method `groups.search()`

        :param q: Search query string.
        :param city_id: City ID. If this parameter is transmitted, country_id is ignored.
        :param count: Number of communities to return. "Note that you can not receive more than first thousand of results, regardless of 'count' and 'offset' values."
        :param country_id: Country ID.
        :param future: '1' - to return only upcoming events. Works with the 'type' = 'event' only.
        :param market: '1' - to return communities with enabled market only.
        :param offset: Offset needed to return a specific subset of results.
        :param sort: Sort order. Possible values: *'0' - default sorting (similar the full version of the site),, *'1' - by growth speed,, *'2'- by the "day attendance/members number" ratio,, *'3' - by the "Likes number/members number" ratio,, *'4' - by the "comments number/members number" ratio,, *'5' - by the "boards entries number/members number" ratio.
        :param type: Community type. Possible values: 'group, page, event.'
        """

        params = self.get_set_params(locals())
        response = await self.api.request("groups.search", params)
        model = GroupsSearchResponse
        return model(**response).response

    async def set_callback_settings(
        self,
        group_id: int,
        api_version: str | None = None,
        audio_new: bool | None = None,
        board_post_delete: bool | None = None,
        board_post_edit: bool | None = None,
        board_post_new: bool | None = None,
        board_post_restore: bool | None = None,
        donut_money_withdraw: bool | None = None,
        donut_money_withdraw_error: bool | None = None,
        donut_subscription_cancelled: bool | None = None,
        donut_subscription_create: bool | None = None,
        donut_subscription_expired: bool | None = None,
        donut_subscription_price_changed: bool | None = None,
        donut_subscription_prolonged: bool | None = None,
        group_change_photo: bool | None = None,
        group_change_settings: bool | None = None,
        group_join: bool | None = None,
        group_leave: bool | None = None,
        group_officers_edit: bool | None = None,
        lead_forms_new: bool | None = None,
        like_add: bool | None = None,
        like_remove: bool | None = None,
        market_comment_delete: bool | None = None,
        market_comment_edit: bool | None = None,
        market_comment_new: bool | None = None,
        market_comment_restore: bool | None = None,
        market_order_edit: bool | None = None,
        market_order_new: bool | None = None,
        message_allow: bool | None = None,
        message_deny: bool | None = None,
        message_edit: bool | None = None,
        message_event: bool | None = None,
        message_new: bool | None = None,
        message_reaction_event: bool | None = None,
        message_read: bool | None = None,
        message_reply: bool | None = None,
        message_typing_state: bool | None = None,
        photo_comment_delete: bool | None = None,
        photo_comment_edit: bool | None = None,
        photo_comment_new: bool | None = None,
        photo_comment_restore: bool | None = None,
        photo_new: bool | None = None,
        poll_vote_new: bool | None = None,
        server_id: int | None = None,
        user_block: bool | None = None,
        user_unblock: bool | None = None,
        video_comment_delete: bool | None = None,
        video_comment_edit: bool | None = None,
        video_comment_new: bool | None = None,
        video_comment_restore: bool | None = None,
        video_new: bool | None = None,
        wall_post_new: bool | None = None,
        wall_reply_delete: bool | None = None,
        wall_reply_edit: bool | None = None,
        wall_reply_new: bool | None = None,
        wall_reply_restore: bool | None = None,
        wall_repost: bool | None = None,
        wall_schedule_post_delete: bool | None = None,
        wall_schedule_post_new: bool | None = None,
        **kwargs: typing.Any,
    ) -> BaseOkResponseModel:
        """Method `groups.setCallbackSettings()`

        :param group_id: Community ID.
        :param api_version:
        :param audio_new: New audios notifications ('0' - disabled, '1' - enabled).
        :param board_post_delete: Board posts deleted notifications ('0' - disabled, '1' - enabled).
        :param board_post_edit: Board posts edited notifications ('0' - disabled, '1' - enabled).
        :param board_post_new: New board posts notifications ('0' - disabled, '1' - enabled).
        :param board_post_restore: Board posts restored notifications ('0' - disabled, '1' - enabled).
        :param donut_money_withdraw:
        :param donut_money_withdraw_error:
        :param donut_subscription_cancelled:
        :param donut_subscription_create:
        :param donut_subscription_expired:
        :param donut_subscription_price_changed:
        :param donut_subscription_prolonged:
        :param group_change_photo:
        :param group_change_settings:
        :param group_join: Joined community notifications ('0' - disabled, '1' - enabled).
        :param group_leave: Left community notifications ('0' - disabled, '1' - enabled).
        :param group_officers_edit:
        :param lead_forms_new: New form in lead forms
        :param like_add:
        :param like_remove:
        :param market_comment_delete: A market comment has been deleted ('0' - disabled, '1' - enabled).
        :param market_comment_edit: A market comment has been edited ('0' - disabled, '1' - enabled).
        :param market_comment_new: New comment to market item notifications ('0' - disabled, '1' - enabled).
        :param market_comment_restore: A market comment has been restored ('0' - disabled, '1' - enabled).
        :param market_order_edit:
        :param market_order_new:
        :param message_allow: Allowed messages notifications ('0' - disabled, '1' - enabled).
        :param message_deny: Denied messages notifications ('0' - disabled, '1' - enabled).
        :param message_edit:
        :param message_event:
        :param message_new: A new incoming message has been received ('0' - disabled, '1' - enabled).
        :param message_reaction_event:
        :param message_read: Messages read notifications ('0' - disabled, '1' - enabled).
        :param message_reply: A new outcoming message has been received ('0' - disabled, '1' - enabled).
        :param message_typing_state:
        :param photo_comment_delete: A photo comment has been deleted ('0' - disabled, '1' - enabled).
        :param photo_comment_edit: A photo comment has been edited ('0' - disabled, '1' - enabled).
        :param photo_comment_new: New comment to photo notifications ('0' - disabled, '1' - enabled).
        :param photo_comment_restore: A photo comment has been restored ('0' - disabled, '1' - enabled).
        :param photo_new: New photos notifications ('0' - disabled, '1' - enabled).
        :param poll_vote_new: A vote in a public poll has been added ('0' - disabled, '1' - enabled).
        :param server_id: Server ID.
        :param user_block: User added to community blacklist
        :param user_unblock: User removed from community blacklist
        :param video_comment_delete: A video comment has been deleted ('0' - disabled, '1' - enabled).
        :param video_comment_edit: A video comment has been edited ('0' - disabled, '1' - enabled).
        :param video_comment_new: New comment to video notifications ('0' - disabled, '1' - enabled).
        :param video_comment_restore: A video comment has been restored ('0' - disabled, '1' - enabled).
        :param video_new: New videos notifications ('0' - disabled, '1' - enabled).
        :param wall_post_new: New wall posts notifications ('0' - disabled, '1' - enabled).
        :param wall_reply_delete: A wall comment has been deleted ('0' - disabled, '1' - enabled).
        :param wall_reply_edit: Wall replies edited notifications ('0' - disabled, '1' - enabled).
        :param wall_reply_new: New wall replies notifications ('0' - disabled, '1' - enabled).
        :param wall_reply_restore: A wall comment has been restored ('0' - disabled, '1' - enabled).
        :param wall_repost: New wall posts notifications ('0' - disabled, '1' - enabled).
        :param wall_schedule_post_delete: Scheduled post removed from time slot ('0' - disabled, '1' - enabled).
        :param wall_schedule_post_new: Scheduled post added to time slot ('0' - disabled, '1' - enabled).
        """

        params = self.get_set_params(locals())
        response = await self.api.request("groups.setCallbackSettings", params)
        model = BaseOkResponse
        return model(**response).response

    async def set_long_poll_settings(
        self,
        group_id: int,
        api_version: str | None = None,
        audio_new: bool | None = None,
        board_post_delete: bool | None = None,
        board_post_edit: bool | None = None,
        board_post_new: bool | None = None,
        board_post_restore: bool | None = None,
        donut_money_withdraw: bool | None = None,
        donut_money_withdraw_error: bool | None = None,
        donut_subscription_cancelled: bool | None = None,
        donut_subscription_create: bool | None = None,
        donut_subscription_expired: bool | None = None,
        donut_subscription_price_changed: bool | None = None,
        donut_subscription_prolonged: bool | None = None,
        enabled: bool | None = None,
        group_change_photo: bool | None = None,
        group_change_settings: bool | None = None,
        group_join: bool | None = None,
        group_leave: bool | None = None,
        group_officers_edit: bool | None = None,
        like_add: bool | None = None,
        like_remove: bool | None = None,
        market_comment_delete: bool | None = None,
        market_comment_edit: bool | None = None,
        market_comment_new: bool | None = None,
        market_comment_restore: bool | None = None,
        message_allow: bool | None = None,
        message_deny: bool | None = None,
        message_edit: bool | None = None,
        message_event: bool | None = None,
        message_new: bool | None = None,
        message_reaction_event: bool | None = None,
        message_read: bool | None = None,
        message_reply: bool | None = None,
        message_typing_state: bool | None = None,
        photo_comment_delete: bool | None = None,
        photo_comment_edit: bool | None = None,
        photo_comment_new: bool | None = None,
        photo_comment_restore: bool | None = None,
        photo_new: bool | None = None,
        poll_vote_new: bool | None = None,
        user_block: bool | None = None,
        user_unblock: bool | None = None,
        video_comment_delete: bool | None = None,
        video_comment_edit: bool | None = None,
        video_comment_new: bool | None = None,
        video_comment_restore: bool | None = None,
        video_new: bool | None = None,
        wall_post_new: bool | None = None,
        wall_reply_delete: bool | None = None,
        wall_reply_edit: bool | None = None,
        wall_reply_new: bool | None = None,
        wall_reply_restore: bool | None = None,
        wall_repost: bool | None = None,
        **kwargs: typing.Any,
    ) -> BaseOkResponseModel:
        """Method `groups.setLongPollSettings()`

        :param group_id: Community ID.
        :param api_version:
        :param audio_new: New audios notifications ('0' - disabled, '1' - enabled).
        :param board_post_delete: Board posts deleted notifications ('0' - disabled, '1' - enabled).
        :param board_post_edit: Board posts edited notifications ('0' - disabled, '1' - enabled).
        :param board_post_new: New board posts notifications ('0' - disabled, '1' - enabled).
        :param board_post_restore: Board posts restored notifications ('0' - disabled, '1' - enabled).
        :param donut_money_withdraw:
        :param donut_money_withdraw_error:
        :param donut_subscription_cancelled:
        :param donut_subscription_create:
        :param donut_subscription_expired:
        :param donut_subscription_price_changed:
        :param donut_subscription_prolonged:
        :param enabled: Sets whether Long Poll is enabled ('0' - disabled, '1' - enabled).
        :param group_change_photo:
        :param group_change_settings:
        :param group_join: Joined community notifications ('0' - disabled, '1' - enabled).
        :param group_leave: Left community notifications ('0' - disabled, '1' - enabled).
        :param group_officers_edit:
        :param like_add:
        :param like_remove:
        :param market_comment_delete: A market comment has been deleted ('0' - disabled, '1' - enabled).
        :param market_comment_edit: A market comment has been edited ('0' - disabled, '1' - enabled).
        :param market_comment_new: New comment to market item notifications ('0' - disabled, '1' - enabled).
        :param market_comment_restore: A market comment has been restored ('0' - disabled, '1' - enabled).
        :param message_allow: Allowed messages notifications ('0' - disabled, '1' - enabled).
        :param message_deny: Denied messages notifications ('0' - disabled, '1' - enabled).
        :param message_edit: A message has been edited ('0' - disabled, '1' - enabled).
        :param message_event:
        :param message_new: A new incoming message has been received ('0' - disabled, '1' - enabled).
        :param message_reaction_event:
        :param message_read: Messages read notifications ('0' - disabled, '1' - enabled).
        :param message_reply: A new outcoming message has been received ('0' - disabled, '1' - enabled).
        :param message_typing_state:
        :param photo_comment_delete: A photo comment has been deleted ('0' - disabled, '1' - enabled).
        :param photo_comment_edit: A photo comment has been edited ('0' - disabled, '1' - enabled).
        :param photo_comment_new: New comment to photo notifications ('0' - disabled, '1' - enabled).
        :param photo_comment_restore: A photo comment has been restored ('0' - disabled, '1' - enabled).
        :param photo_new: New photos notifications ('0' - disabled, '1' - enabled).
        :param poll_vote_new: A vote in a public poll has been added ('0' - disabled, '1' - enabled).
        :param user_block: User added to community blacklist
        :param user_unblock: User removed from community blacklist
        :param video_comment_delete: A video comment has been deleted ('0' - disabled, '1' - enabled).
        :param video_comment_edit: A video comment has been edited ('0' - disabled, '1' - enabled).
        :param video_comment_new: New comment to video notifications ('0' - disabled, '1' - enabled).
        :param video_comment_restore: A video comment has been restored ('0' - disabled, '1' - enabled).
        :param video_new: New videos notifications ('0' - disabled, '1' - enabled).
        :param wall_post_new: New wall posts notifications ('0' - disabled, '1' - enabled).
        :param wall_reply_delete: A wall comment has been deleted ('0' - disabled, '1' - enabled).
        :param wall_reply_edit: Wall replies edited notifications ('0' - disabled, '1' - enabled).
        :param wall_reply_new: New wall replies notifications ('0' - disabled, '1' - enabled).
        :param wall_reply_restore: A wall comment has been restored ('0' - disabled, '1' - enabled).
        :param wall_repost: New wall posts notifications ('0' - disabled, '1' - enabled).
        """

        params = self.get_set_params(locals())
        response = await self.api.request("groups.setLongPollSettings", params)
        model = BaseOkResponse
        return model(**response).response

    async def set_settings(
        self,
        group_id: int,
        bot_online_booking_enabled: bool | None = None,
        bots_add_to_chat: bool | None = None,
        bots_capabilities: bool | None = None,
        bots_start_button: bool | None = None,
        messages: bool | None = None,
        **kwargs: typing.Any,
    ) -> BaseOkResponseModel:
        """Method `groups.setSettings()`

        :param group_id:
        :param bot_online_booking_enabled: If this setting is enabled then online booking chatbot add in your community chats
        :param bots_add_to_chat: If this setting is enabled then users can add your community to a chat
        :param bots_capabilities: By enabling bot abilities, you can send users messages with a customized keyboard attached as well as use other promotional abilities
        :param bots_start_button: If this setting is enabled, users will see a Start button when they start a chat with your community for the first time
        :param messages:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("groups.setSettings", params)
        model = BaseOkResponse
        return model(**response).response

    async def set_user_note(
        self,
        group_id: int,
        user_id: int,
        note: str | None = None,
        **kwargs: typing.Any,
    ) -> bool:
        """Method `groups.setUserNote()`

        :param group_id:
        :param user_id:
        :param note: Note body
        """

        params = self.get_set_params(locals())
        response = await self.api.request("groups.setUserNote", params)
        model = BaseBoolResponse
        return model(**response).response

    async def tag_add(
        self,
        group_id: int,
        tag_name: str,
        tag_color: str | None = None,
        **kwargs: typing.Any,
    ) -> bool:
        """Method `groups.tagAdd()`

        :param group_id:
        :param tag_name:
        :param tag_color:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("groups.tagAdd", params)
        model = BaseBoolResponse
        return model(**response).response

    async def tag_bind(
        self,
        act: str,
        group_id: int,
        tag_id: int,
        user_id: int,
        **kwargs: typing.Any,
    ) -> bool:
        """Method `groups.tagBind()`

        :param act: Describe the action
        :param group_id:
        :param tag_id:
        :param user_id:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("groups.tagBind", params)
        model = BaseBoolResponse
        return model(**response).response

    async def tag_delete(
        self,
        group_id: int,
        tag_id: int,
        **kwargs: typing.Any,
    ) -> bool:
        """Method `groups.tagDelete()`

        :param group_id:
        :param tag_id:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("groups.tagDelete", params)
        model = BaseBoolResponse
        return model(**response).response

    async def tag_update(
        self,
        group_id: int,
        tag_id: int,
        tag_name: str,
        **kwargs: typing.Any,
    ) -> bool:
        """Method `groups.tagUpdate()`

        :param group_id:
        :param tag_id:
        :param tag_name:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("groups.tagUpdate", params)
        model = BaseBoolResponse
        return model(**response).response

    async def toggle_market(
        self,
        group_id: int,
        state: str,
        ref: str | None = None,
        **kwargs: typing.Any,
    ) -> BaseOkResponseModel:
        """Method `groups.toggleMarket()`

        :param group_id:
        :param state:
        :param ref:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("groups.toggleMarket", params)
        model = BaseOkResponse
        return model(**response).response

    async def unban(
        self,
        group_id: int,
        owner_id: int | None = None,
        **kwargs: typing.Any,
    ) -> BaseOkResponseModel:
        """Method `groups.unban()`

        :param group_id:
        :param owner_id:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("groups.unban", params)
        model = BaseOkResponse
        return model(**response).response


__all__ = ("GroupsCategory",)



import typing

from vkbottle_types.methods.base_category import BaseCategory
from vkbottle_types.responses.podcasts import *  # noqa: F401,F403  # type: ignore


class PodcastsCategory(BaseCategory):
    async def search_podcast(
        self,
        search_string: str,
        count: int | None = None,
        offset: int | None = None,
        **kwargs: typing.Any,
    ) -> PodcastsSearchPodcastResponseModel:
        """Method `podcasts.searchPodcast()`

        :param search_string:
        :param count:
        :param offset:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("podcasts.searchPodcast", params)
        model = PodcastsSearchPodcastResponse
        return model(**response).response


__all__ = ("PodcastsCategory",)



from vkbottle_types.base_model import BaseModel, Field
from vkbottle_types.objects import GiftsGift
from vkbottle_types.responses.base_response import BaseResponse


class GiftsGetResponseModel(BaseModel):
    count: int = Field()
    items: list["GiftsGift"] = Field()


class GiftsGetResponse(BaseResponse):
    response: "GiftsGetResponseModel" = Field()



from vkbottle_types.base_model import BaseModel, Field
from vkbottle_types.responses.base_response import BaseResponse


class AuthRestoreResponseModel(BaseModel):
    success: int | None = Field(
        default=None,
    )
    sid: str | None = Field(
        default=None,
    )


class AuthRestoreResponse(BaseResponse):
    response: "AuthRestoreResponseModel" = Field()



import typing

from vkbottle_types.methods.base_category import BaseCategory
from vkbottle_types.objects import BaseCountry, DatabaseCitiesFields, DatabaseCityById, DatabaseSchoolClass, DatabaseStation
from vkbottle_types.responses.database import *  # noqa: F401,F403  # type: ignore


class DatabaseCategory(BaseCategory):
    async def get_chairs(
        self,
        faculty_id: int,
        count: int | None = None,
        offset: int | None = None,
        **kwargs: typing.Any,
    ) -> DatabaseGetChairsResponseModel:
        """Method `database.getChairs()`

        :param faculty_id: id of the faculty to get chairs from
        :param count: amount of chairs to get
        :param offset: offset required to get a certain subset of chairs
        """

        params = self.get_set_params(locals())
        response = await self.api.request("database.getChairs", params)
        model = DatabaseGetChairsResponse
        return model(**response).response

    async def get_cities(
        self,
        count: int | None = None,
        fields: list[DatabaseCitiesFields] | None = None,
        need_all: bool | None = None,
        offset: int | None = None,
        q: str | None = None,
        region_id: int | None = None,
        **kwargs: typing.Any,
    ) -> DatabaseGetCitiesResponseModel:
        """Method `database.getCities()`

        :param count: Number of cities to return.
        :param fields: Cities fields to return. Sample values: 'fias_guid'
        :param need_all: '1' - to return all cities in the country, '0' - to return major cities in the country (default),
        :param offset: Offset needed to return a specific subset of cities.
        :param q: Search query.
        :param region_id: Region ID.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("database.getCities", params)
        model = DatabaseGetCitiesResponse
        return model(**response).response

    async def get_cities_by_id(
        self,
        city_ids: list[int] | None = None,
        fields: list[DatabaseCitiesFields] | None = None,
        **kwargs: typing.Any,
    ) -> list[DatabaseCityById]:
        """Method `database.getCitiesById()`

        :param city_ids: City IDs.
        :param fields: Cities fields to return. Sample values: 'fias_guid'
        """

        params = self.get_set_params(locals())
        response = await self.api.request("database.getCitiesById", params)
        model = DatabaseGetCitiesByIdResponse
        return model(**response).response

    async def get_countries(
        self,
        code: str | None = None,
        count: int | None = None,
        need_all: bool | None = None,
        offset: int | None = None,
        **kwargs: typing.Any,
    ) -> DatabaseGetCountriesResponseModel:
        """Method `database.getCountries()`

        :param code: Country codes in [vk.com/dev/country_codes|ISO 3166-1 alpha-2] standard.
        :param count: Number of countries to return.
        :param need_all: '1' - to return a full list of all countries, '0' - to return a list of countries near the current user's country (default).
        :param offset: Offset needed to return a specific subset of countries.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("database.getCountries", params)
        model = DatabaseGetCountriesResponse
        return model(**response).response

    async def get_countries_by_id(
        self,
        country_ids: list[int] | None = None,
        **kwargs: typing.Any,
    ) -> list[BaseCountry]:
        """Method `database.getCountriesById()`

        :param country_ids: Country IDs.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("database.getCountriesById", params)
        model = DatabaseGetCountriesByIdResponse
        return model(**response).response

    async def get_faculties(
        self,
        university_id: int,
        count: int | None = None,
        offset: int | None = None,
        **kwargs: typing.Any,
    ) -> DatabaseGetFacultiesResponseModel:
        """Method `database.getFaculties()`

        :param university_id: University ID.
        :param count: Number of faculties to return.
        :param offset: Offset needed to return a specific subset of faculties.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("database.getFaculties", params)
        model = DatabaseGetFacultiesResponse
        return model(**response).response

    async def get_metro_stations(
        self,
        city_id: int,
        count: int | None = None,
        extended: bool | None = None,
        offset: int | None = None,
        **kwargs: typing.Any,
    ) -> DatabaseGetMetroStationsResponseModel:
        """Method `database.getMetroStations()`

        :param city_id:
        :param count:
        :param extended:
        :param offset:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("database.getMetroStations", params)
        model = DatabaseGetMetroStationsResponse
        return model(**response).response

    async def get_metro_stations_by_id(
        self,
        station_ids: list[int] | None = None,
        **kwargs: typing.Any,
    ) -> list[DatabaseStation]:
        """Method `database.getMetroStationsById()`

        :param station_ids:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("database.getMetroStationsById", params)
        model = DatabaseGetMetroStationsByIdResponse
        return model(**response).response

    async def get_regions(
        self,
        count: int | None = None,
        offset: int | None = None,
        q: str | None = None,
        **kwargs: typing.Any,
    ) -> DatabaseGetRegionsResponseModel:
        """Method `database.getRegions()`

        :param count: Number of regions to return.
        :param offset: Offset needed to return specific subset of regions.
        :param q: Search query.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("database.getRegions", params)
        model = DatabaseGetRegionsResponse
        return model(**response).response

    async def get_school_classes(
        self,
        country_id: int | None = None,
        **kwargs: typing.Any,
    ) -> list[DatabaseSchoolClass]:
        """Method `database.getSchoolClasses()`

        :param country_id: Country ID.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("database.getSchoolClasses", params)
        model = DatabaseGetSchoolClassesNewResponse
        return model(**response).response

    async def get_schools(
        self,
        city_id: int,
        count: int | None = None,
        offset: int | None = None,
        q: str | None = None,
        **kwargs: typing.Any,
    ) -> DatabaseGetSchoolsResponseModel:
        """Method `database.getSchools()`

        :param city_id: City ID.
        :param count: Number of schools to return.
        :param offset: Offset needed to return a specific subset of schools.
        :param q: Search query.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("database.getSchools", params)
        model = DatabaseGetSchoolsResponse
        return model(**response).response

    async def get_universities(
        self,
        city_id: int | None = None,
        count: int | None = None,
        offset: int | None = None,
        q: str | None = None,
        **kwargs: typing.Any,
    ) -> DatabaseGetUniversitiesResponseModel:
        """Method `database.getUniversities()`

        :param city_id: City ID.
        :param count: Number of universities to return.
        :param offset: Offset needed to return a specific subset of universities.
        :param q: Search query.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("database.getUniversities", params)
        model = DatabaseGetUniversitiesResponse
        return model(**response).response


__all__ = ("DatabaseCategory",)



import enum
import math
import sys

import pydantic
import typing_extensions as typing
from pydantic_core import CoreSchema, core_schema

NOT_SUPPORTED: typing.Final = "NOT_SUPPORTED"


def _is_friend(bases: tuple[type[typing.Any], ...], /) -> bool:
    return any(friend in bases for friend in ENUM_FRIENDS)


if typing.TYPE_CHECKING:

    @typing.dataclass_transform(
        kw_only_default=True,
        field_specifiers=(pydantic.Field, pydantic.PrivateAttr),
    )
    class BaseModel(pydantic.BaseModel):
        @classmethod
        def from_raw(cls, data: str | bytes, /, *, strict: bool = False) -> typing.Self: ...

        @classmethod
        def from_dict(cls, data: dict[str, typing.Any], /) -> typing.Self: ...

        def to_dict(self, **kwargs: typing.Any) -> dict[str, typing.Any]: ...

        def to_raw(self, **kwargs: typing.Any) -> str: ...

else:

    class BaseModel(pydantic.BaseModel):
        model_config = pydantic.ConfigDict(frozen=True)

        @classmethod
        def from_raw(cls, data, /, *, strict=False):
            return cls.model_validate_json(data, strict=strict)

        @classmethod
        def from_dict(cls, data, /):
            return cls(**data)

        def to_dict(self, **kwargs):
            return self.model_dump(**kwargs)

        def to_raw(self, **kwargs):
            return self.model_dump_json(**kwargs)


class StrEnum(str, enum.Enum):
    def __str__(self) -> str:
        return self.value


class IntEnum(int, enum.Enum):
    def __int__(self) -> int:
        return self.value

    def __float__(self) -> float:
        return float(self.value)

    def __index__(self) -> int:
        return self.value


class FloatEnum(float, enum.Enum):
    def __int__(self) -> int:
        return int(self.value)

    def __float__(self) -> float:
        return self.value


class BaseEnumMeta(enum.EnumMeta, type):
    if typing.TYPE_CHECKING:

        class _BaseEnumMeta(enum.Enum):  # noqa
            NOT_SUPPORTED_MEMBER = enum.auto()

        NOT_SUPPORTED_MEMBER: typing.Literal[_BaseEnumMeta.NOT_SUPPORTED_MEMBER]

    else:

        @staticmethod
        def __get_pydantic_core_schema__(_cls: typing.Any, _source_type: typing.Any, _handler: pydantic.GetCoreSchemaHandler) -> CoreSchema:
            return core_schema.no_info_after_validator_function(
                function=lambda x: _cls(x),  # type: ignore
                schema=getattr(core_schema, f"{_cls.__bases__[0].__name__}_schema", core_schema.any_schema)(),
            )

        @staticmethod
        def _member_missing(cls, value):
            return cls._member_map_["NOT_SUPPORTED_MEMBER"]

        def __new__(
            metacls,
            cls,
            bases,
            classdict,
            *,
            boundary=None,
            _simple=False,
            **kwds,
        ):
            if _is_friend(bases):
                classdict["NOT_SUPPORTED_MEMBER"] = next(
                    (value for base, value in NOT_SUPPORTED_VALUES.items() if base in bases),
                    NOT_SUPPORTED,
                )

            classdict["_missing_"] = classmethod(BaseEnumMeta._member_missing)
            classdict["__get_pydantic_core_schema__"] = classmethod(BaseEnumMeta.__get_pydantic_core_schema__)
            kwargs = dict(
                metacls=metacls,
                cls=cls,
                bases=bases,
                classdict=classdict,
            )

            if sys.version_info >= (3, 11):
                kwargs.update(
                    dict(
                        boundary=boundary,
                        _simple=_simple,
                    ),
                )

            return super().__new__(**kwargs, **kwds)


ENUM_FRIENDS: typing.Final = (str, int, float, StrEnum, IntEnum, FloatEnum)
NOT_SUPPORTED_VALUES: typing.Final = {
    str: NOT_SUPPORTED,
    int: sys.maxsize,
    float: math.inf,
    StrEnum: NOT_SUPPORTED,
    IntEnum: sys.maxsize,
    FloatEnum: math.inf,
    enum.IntEnum: sys.maxsize,
}


if sys.version_info >= (3, 11):
    NOT_SUPPORTED_VALUES.update({enum.StrEnum: NOT_SUPPORTED})


Field = pydantic.Field


__all__ = ("BaseEnumMeta", "BaseModel", "Field", "StrEnum", "IntEnum", "FloatEnum")



import typing

from vkbottle_types.methods.base_category import BaseCategory
from vkbottle_types.objects import BaseUserGroupFields, FaveTag
from vkbottle_types.responses.base import (
    BaseBoolResponse,
    BaseOkResponse,
    BaseOkResponseModel,
)
from vkbottle_types.responses.fave import *  # noqa: F401,F403  # type: ignore


class FaveCategory(BaseCategory):
    async def add_article(
        self,
        url: str,
        **kwargs: typing.Any,
    ) -> BaseOkResponseModel:
        """Method `fave.addArticle()`

        :param url:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("fave.addArticle", params)
        model = BaseOkResponse
        return model(**response).response

    async def add_link(
        self,
        link: str,
        **kwargs: typing.Any,
    ) -> BaseOkResponseModel:
        """Method `fave.addLink()`

        :param link: Link URL.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("fave.addLink", params)
        model = BaseOkResponse
        return model(**response).response

    async def add_page(
        self,
        group_id: int | None = None,
        user_id: int | None = None,
        **kwargs: typing.Any,
    ) -> BaseOkResponseModel:
        """Method `fave.addPage()`

        :param group_id:
        :param user_id:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("fave.addPage", params)
        model = BaseOkResponse
        return model(**response).response

    async def add_post(
        self,
        id: int,
        owner_id: int,
        access_key: str | None = None,
        **kwargs: typing.Any,
    ) -> BaseOkResponseModel:
        """Method `fave.addPost()`

        :param id:
        :param owner_id:
        :param access_key:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("fave.addPost", params)
        model = BaseOkResponse
        return model(**response).response

    async def add_product(
        self,
        id: int,
        owner_id: int,
        access_key: str | None = None,
        **kwargs: typing.Any,
    ) -> BaseOkResponseModel:
        """Method `fave.addProduct()`

        :param id:
        :param owner_id:
        :param access_key:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("fave.addProduct", params)
        model = BaseOkResponse
        return model(**response).response

    async def add_tag(
        self,
        name: str | None = None,
        position: str | None = None,
        **kwargs: typing.Any,
    ) -> "FaveTag":
        """Method `fave.addTag()`

        :param name:
        :param position:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("fave.addTag", params)
        model = FaveAddTagResponse
        return model(**response).response

    async def add_video(
        self,
        id: int,
        owner_id: int,
        access_key: str | None = None,
        **kwargs: typing.Any,
    ) -> BaseOkResponseModel:
        """Method `fave.addVideo()`

        :param id:
        :param owner_id:
        :param access_key:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("fave.addVideo", params)
        model = BaseOkResponse
        return model(**response).response

    async def edit_tag(
        self,
        id: int,
        name: str,
        **kwargs: typing.Any,
    ) -> BaseOkResponseModel:
        """Method `fave.editTag()`

        :param id:
        :param name:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("fave.editTag", params)
        model = BaseOkResponse
        return model(**response).response

    @typing.overload
    async def get(
        self,
        extended: typing.Literal[True],
        count: int | None = None,
        fields: str | None = None,
        is_from_snackbar: bool | None = None,
        item_type: str | None = None,
        offset: int | None = None,
        tag_id: int | None = None,
        **kwargs: typing.Any,
    ) -> FaveGetExtendedResponseModel: ...

    @typing.overload
    async def get(
        self,
        extended: typing.Literal[False] | None = None,
        count: int | None = None,
        fields: str | None = None,
        is_from_snackbar: bool | None = None,
        item_type: str | None = None,
        offset: int | None = None,
        tag_id: int | None = None,
        **kwargs: typing.Any,
    ) -> FaveGetResponseModel: ...

    async def get(
        self,
        extended: bool | None = None,
        count: int | None = None,
        fields: str | None = None,
        is_from_snackbar: bool | None = None,
        item_type: str | None = None,
        offset: int | None = None,
        tag_id: int | None = None,
        **kwargs: typing.Any,
    ) -> FaveGetResponseModel | FaveGetExtendedResponseModel:
        """Method `fave.get()`

        :param extended: '1' - to return additional 'wall', 'profiles', and 'groups' fields. By default: '0'.
        :param count: Number of users to return.
        :param fields:
        :param is_from_snackbar:
        :param item_type:
        :param offset: Offset needed to return a specific subset of users.
        :param tag_id: Tag ID.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("fave.get", params)
        model = self.get_model(
            ((("extended",), FaveGetExtendedResponse),),
            default=FaveGetResponse,
            params=params,
        )
        return model(**response).response

    async def get_pages(
        self,
        count: int | None = None,
        fields: list[BaseUserGroupFields] | None = None,
        offset: int | None = None,
        tag_id: int | None = None,
        type: str | None = None,
        **kwargs: typing.Any,
    ) -> FaveGetPagesResponseModel:
        """Method `fave.getPages()`

        :param count:
        :param fields:
        :param offset:
        :param tag_id:
        :param type:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("fave.getPages", params)
        model = FaveGetPagesResponse
        return model(**response).response

    async def get_tags(
        self,
        **kwargs: typing.Any,
    ) -> FaveGetTagsResponseModel:
        """Method `fave.getTags()`"""

        params = self.get_set_params(locals())
        response = await self.api.request("fave.getTags", params)
        model = FaveGetTagsResponse
        return model(**response).response

    async def mark_seen(
        self,
        **kwargs: typing.Any,
    ) -> bool:
        """Method `fave.markSeen()`"""

        params = self.get_set_params(locals())
        response = await self.api.request("fave.markSeen", params)
        model = BaseBoolResponse
        return model(**response).response

    async def remove_article(
        self,
        article_id: int,
        owner_id: int,
        **kwargs: typing.Any,
    ) -> bool:
        """Method `fave.removeArticle()`

        :param article_id:
        :param owner_id:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("fave.removeArticle", params)
        model = BaseBoolResponse
        return model(**response).response

    async def remove_link(
        self,
        link: str | None = None,
        link_id: str | None = None,
        **kwargs: typing.Any,
    ) -> BaseOkResponseModel:
        """Method `fave.removeLink()`

        :param link: Link URL
        :param link_id: Link ID (can be obtained by [vk.com/dev/faves.getLinks|faves.getLinks] method).
        """

        params = self.get_set_params(locals())
        response = await self.api.request("fave.removeLink", params)
        model = BaseOkResponse
        return model(**response).response

    async def remove_page(
        self,
        group_id: int | None = None,
        user_id: int | None = None,
        **kwargs: typing.Any,
    ) -> BaseOkResponseModel:
        """Method `fave.removePage()`

        :param group_id:
        :param user_id:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("fave.removePage", params)
        model = BaseOkResponse
        return model(**response).response

    async def remove_post(
        self,
        id: int,
        owner_id: int,
        **kwargs: typing.Any,
    ) -> BaseOkResponseModel:
        """Method `fave.removePost()`

        :param id:
        :param owner_id:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("fave.removePost", params)
        model = BaseOkResponse
        return model(**response).response

    async def remove_product(
        self,
        id: int,
        owner_id: int,
        **kwargs: typing.Any,
    ) -> BaseOkResponseModel:
        """Method `fave.removeProduct()`

        :param id:
        :param owner_id:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("fave.removeProduct", params)
        model = BaseOkResponse
        return model(**response).response

    async def remove_tag(
        self,
        id: int,
        **kwargs: typing.Any,
    ) -> BaseOkResponseModel:
        """Method `fave.removeTag()`

        :param id:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("fave.removeTag", params)
        model = BaseOkResponse
        return model(**response).response

    async def remove_video(
        self,
        id: int,
        owner_id: int,
        **kwargs: typing.Any,
    ) -> BaseOkResponseModel:
        """Method `fave.removeVideo()`

        :param id:
        :param owner_id:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("fave.removeVideo", params)
        model = BaseOkResponse
        return model(**response).response

    async def reorder_tags(
        self,
        ids: list[int],
        **kwargs: typing.Any,
    ) -> BaseOkResponseModel:
        """Method `fave.reorderTags()`

        :param ids:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("fave.reorderTags", params)
        model = BaseOkResponse
        return model(**response).response

    async def set_page_tags(
        self,
        group_id: int | None = None,
        tag_ids: list[int] | None = None,
        user_id: int | None = None,
        **kwargs: typing.Any,
    ) -> BaseOkResponseModel:
        """Method `fave.setPageTags()`

        :param group_id:
        :param tag_ids:
        :param user_id:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("fave.setPageTags", params)
        model = BaseOkResponse
        return model(**response).response

    async def set_tags(
        self,
        item_id: int | None = None,
        item_owner_id: int | None = None,
        item_type: str | None = None,
        link_id: str | None = None,
        link_url: str | None = None,
        tag_ids: list[int] | None = None,
        **kwargs: typing.Any,
    ) -> BaseOkResponseModel:
        """Method `fave.setTags()`

        :param item_id:
        :param item_owner_id:
        :param item_type:
        :param link_id:
        :param link_url:
        :param tag_ids:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("fave.setTags", params)
        model = BaseOkResponse
        return model(**response).response

    async def track_page_interaction(
        self,
        group_id: int | None = None,
        user_id: int | None = None,
        **kwargs: typing.Any,
    ) -> BaseOkResponseModel:
        """Method `fave.trackPageInteraction()`

        :param group_id:
        :param user_id:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("fave.trackPageInteraction", params)
        model = BaseOkResponse
        return model(**response).response


__all__ = ("FaveCategory",)



from vkbottle_types.base_model import BaseModel, Field
from vkbottle_types.responses.base_response import BaseResponse


class TranslationsTranslateResponseModel(BaseModel):
    texts: list[str] | None = Field(
        default=None,
    )
    source_lang: str | None = Field(
        default=None,
    )


class TranslationsTranslateResponse(BaseResponse):
    response: "TranslationsTranslateResponseModel" = Field()



from vkbottle_types.base_model import BaseModel, Field
from vkbottle_types.objects import AppWidgetsPhoto, AppWidgetsPhotos
from vkbottle_types.responses.base_response import BaseResponse


class AppWidgetsGetAppImageUploadServerResponseModel(BaseModel):
    upload_url: str | None = Field(
        default=None,
    )


class AppWidgetsGetAppImageUploadServerResponse(BaseResponse):
    response: "AppWidgetsGetAppImageUploadServerResponseModel" = Field()


class AppWidgetsGetAppImagesResponse(BaseResponse):
    response: "AppWidgetsPhotos" = Field()


class AppWidgetsGetGroupImageUploadServerResponseModel(BaseModel):
    upload_url: str | None = Field(
        default=None,
    )


class AppWidgetsGetGroupImageUploadServerResponse(BaseResponse):
    response: "AppWidgetsGetGroupImageUploadServerResponseModel" = Field()


class AppWidgetsGetGroupImagesResponse(BaseResponse):
    response: "AppWidgetsPhotos" = Field()


class AppWidgetsGetImagesByIdResponse(BaseResponse):
    response: list["AppWidgetsPhoto"] = Field()


class AppWidgetsSaveAppImageResponse(BaseResponse):
    response: "AppWidgetsPhoto" = Field()


class AppWidgetsSaveGroupImageResponse(BaseResponse):
    response: "AppWidgetsPhoto" = Field()



import typing

from vkbottle_types.methods.base_category import BaseCategory
from vkbottle_types.objects import BaseUploadServer, PhotosPhoto, PhotosPhotoAlbumFull, PhotosPhotoTag, PhotosPhotoUpload, UsersFields
from vkbottle_types.responses.base import (
    BaseBoolResponse,
    BaseGetUploadServerResponse,
    BaseOkResponse,
    BaseOkResponseModel,
)
from vkbottle_types.responses.photos import *  # noqa: F401,F403  # type: ignore


class PhotosCategory(BaseCategory):
    async def confirm_tag(
        self,
        photo_id: str,
        tag_id: int,
        owner_id: int | None = None,
        **kwargs: typing.Any,
    ) -> BaseOkResponseModel:
        """Method `photos.confirmTag()`

        :param photo_id: Photo ID.
        :param tag_id: Tag ID.
        :param owner_id: ID of the user or community that owns the photo.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("photos.confirmTag", params)
        model = BaseOkResponse
        return model(**response).response

    async def copy(
        self,
        owner_id: int,
        photo_id: int,
        access_key: str | None = None,
        **kwargs: typing.Any,
    ) -> int:
        """Method `photos.copy()`

        :param owner_id: photo's owner ID
        :param photo_id: photo ID
        :param access_key: for private photos
        """

        params = self.get_set_params(locals())
        response = await self.api.request("photos.copy", params)
        model = PhotosCopyResponse
        return model(**response).response

    async def create_album(
        self,
        title: str,
        comments_disabled: bool | None = None,
        description: str | None = None,
        group_id: int | None = None,
        privacy_comment: list[str] | None = None,
        privacy_view: list[str] | None = None,
        upload_by_admins_only: bool | None = None,
        **kwargs: typing.Any,
    ) -> "PhotosPhotoAlbumFull":
        """Method `photos.createAlbum()`

        :param title: Album title.
        :param comments_disabled:
        :param description: Album description.
        :param group_id: ID of the community in which the album will be created.
        :param privacy_comment:
        :param privacy_view:
        :param upload_by_admins_only:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("photos.createAlbum", params)
        model = PhotosCreateAlbumResponse
        return model(**response).response

    async def create_comment(
        self,
        photo_id: int,
        access_key: str | None = None,
        attachments: list[str] | None = None,
        from_group: bool | None = None,
        guid: str | None = None,
        message: str | None = None,
        owner_id: int | None = None,
        reply_to_comment: int | None = None,
        sticker_id: int | None = None,
        **kwargs: typing.Any,
    ) -> int:
        """Method `photos.createComment()`

        :param photo_id: Photo ID.
        :param access_key:
        :param attachments: (Required if 'message' is not set.) List of objects attached to the post, in the following format: "<owner_id>_<media_id>,<owner_id>_<media_id>", '' - Type of media attachment: 'photo' - photo, 'video' - video, 'audio' - audio, 'doc' - document, '<owner_id>' - Media attachment owner ID. '<media_id>' - Media attachment ID. Example: "photo100172_166443618,photo66748_265827614"
        :param from_group: '1' - to post a comment from the community
        :param guid:
        :param message: Comment text.
        :param owner_id: ID of the user or community that owns the photo.
        :param reply_to_comment:
        :param sticker_id:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("photos.createComment", params)
        model = PhotosCreateCommentResponse
        return model(**response).response

    async def delete(
        self,
        owner_id: int | None = None,
        photo_id: int | None = None,
        photos: list[str] | None = None,
        **kwargs: typing.Any,
    ) -> BaseOkResponseModel:
        """Method `photos.delete()`

        :param owner_id: ID of the user or community that owns the photo.
        :param photo_id: Photo ID.
        :param photos:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("photos.delete", params)
        model = BaseOkResponse
        return model(**response).response

    async def delete_album(
        self,
        album_id: int,
        group_id: int | None = None,
        **kwargs: typing.Any,
    ) -> BaseOkResponseModel:
        """Method `photos.deleteAlbum()`

        :param album_id: Album ID.
        :param group_id: ID of the community that owns the album.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("photos.deleteAlbum", params)
        model = BaseOkResponse
        return model(**response).response

    async def delete_comment(
        self,
        comment_id: int,
        owner_id: int | None = None,
        **kwargs: typing.Any,
    ) -> bool:
        """Method `photos.deleteComment()`

        :param comment_id: Comment ID.
        :param owner_id: ID of the user or community that owns the photo.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("photos.deleteComment", params)
        model = BaseBoolResponse
        return model(**response).response

    async def edit(
        self,
        photo_id: int,
        caption: str | None = None,
        delete_place: bool | None = None,
        foursquare_id: str | None = None,
        latitude: float | None = None,
        longitude: float | None = None,
        owner_id: int | None = None,
        place_str: str | None = None,
        **kwargs: typing.Any,
    ) -> BaseOkResponseModel:
        """Method `photos.edit()`

        :param photo_id: Photo ID.
        :param caption: New caption for the photo. If this parameter is not set, it is considered to be equal to an empty string.
        :param delete_place:
        :param foursquare_id:
        :param latitude:
        :param longitude:
        :param owner_id: ID of the user or community that owns the photo.
        :param place_str:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("photos.edit", params)
        model = BaseOkResponse
        return model(**response).response

    async def edit_album(
        self,
        album_id: int,
        comments_disabled: bool | None = None,
        description: str | None = None,
        owner_id: int | None = None,
        privacy_comment: list[str] | None = None,
        privacy_view: list[str] | None = None,
        title: str | None = None,
        upload_by_admins_only: bool | None = None,
        **kwargs: typing.Any,
    ) -> BaseOkResponseModel:
        """Method `photos.editAlbum()`

        :param album_id: ID of the photo album to be edited.
        :param comments_disabled:
        :param description: New album description.
        :param owner_id: ID of the user or community that owns the album.
        :param privacy_comment:
        :param privacy_view:
        :param title: New album title.
        :param upload_by_admins_only:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("photos.editAlbum", params)
        model = BaseOkResponse
        return model(**response).response

    async def edit_comment(
        self,
        comment_id: int,
        attachments: list[str] | None = None,
        message: str | None = None,
        owner_id: int | None = None,
        **kwargs: typing.Any,
    ) -> BaseOkResponseModel:
        """Method `photos.editComment()`

        :param comment_id: Comment ID.
        :param attachments: (Required if 'message' is not set.) List of objects attached to the post, in the following format: "<owner_id>_<media_id>,<owner_id>_<media_id>", '' - Type of media attachment: 'photo' - photo, 'video' - video, 'audio' - audio, 'doc' - document, '<owner_id>' - Media attachment owner ID. '<media_id>' - Media attachment ID. Example: "photo100172_166443618,photo66748_265827614"
        :param message: New text of the comment.
        :param owner_id: ID of the user or community that owns the photo.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("photos.editComment", params)
        model = BaseOkResponse
        return model(**response).response

    async def get(
        self,
        album_id: str | None = None,
        count: int | None = None,
        extended: bool | None = None,
        feed: int | None = None,
        feed_type: str | None = None,
        offset: int | None = None,
        owner_id: int | None = None,
        photo_ids: list[str] | None = None,
        photo_sizes: bool | None = None,
        rev: bool | None = None,
        **kwargs: typing.Any,
    ) -> PhotosGetResponseModel:
        """Method `photos.get()`

        :param album_id: Photo album ID. To return information about photos from service albums, use the following string values: 'profile, wall, saved'.
        :param count:
        :param extended: '1' - to return additional 'likes', 'comments', and 'tags' fields, '0' - (default)
        :param feed: unixtime, that can be obtained with [vk.com/dev/newsfeed.get|newsfeed.get] method in date field to get all photos uploaded by the user on a specific day, or photos the user has been tagged on. Also, 'uid' parameter of the user the event happened with shall be specified.
        :param feed_type: Type of feed obtained in 'feed' field of the method.
        :param offset:
        :param owner_id: ID of the user or community that owns the photos. Use a negative value to designate a community ID.
        :param photo_ids: Photo IDs.
        :param photo_sizes: '1' - to return photo sizes in a [vk.com/dev/photo_sizes|special format]
        :param rev: Sort order: '1' - reverse chronological, '0' - chronological
        """

        params = self.get_set_params(locals())
        response = await self.api.request("photos.get", params)
        model = PhotosGetResponse
        return model(**response).response

    async def get_albums(
        self,
        album_ids: list[int] | None = None,
        count: int | None = None,
        need_covers: bool | None = None,
        need_system: bool | None = None,
        offset: int | None = None,
        owner_id: int | None = None,
        photo_sizes: bool | None = None,
        **kwargs: typing.Any,
    ) -> PhotosGetAlbumsResponseModel:
        """Method `photos.getAlbums()`

        :param album_ids: Album IDs.
        :param count: Number of albums to return.
        :param need_covers: '1' - to return an additional 'thumb_src' field, '0' - (default)
        :param need_system: '1' - to return system albums with negative IDs
        :param offset: Offset needed to return a specific subset of albums.
        :param owner_id: ID of the user or community that owns the albums.
        :param photo_sizes: '1' - to return photo sizes in a
        """

        params = self.get_set_params(locals())
        response = await self.api.request("photos.getAlbums", params)
        model = PhotosGetAlbumsResponse
        return model(**response).response

    async def get_albums_count(
        self,
        group_id: int | None = None,
        need_system: bool | None = None,
        user_id: int | None = None,
        **kwargs: typing.Any,
    ) -> int:
        """Method `photos.getAlbumsCount()`

        :param group_id: Community ID.
        :param need_system:
        :param user_id: User ID.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("photos.getAlbumsCount", params)
        model = PhotosGetAlbumsCountResponse
        return model(**response).response

    async def get_all(
        self,
        count: int | None = None,
        extended: bool | None = None,
        need_hidden: bool | None = None,
        no_service_albums: bool | None = None,
        offset: int | None = None,
        owner_id: int | None = None,
        photo_sizes: bool | None = None,
        skip_hidden: bool | None = None,
        **kwargs: typing.Any,
    ) -> PhotosGetAllResponseModel:
        """Method `photos.getAll()`

        :param count: Number of photos to return.
        :param extended: '1' - to return detailed information about photos
        :param need_hidden: '1' - to show information about photos being hidden from the block above the wall.
        :param no_service_albums: '1' - to return photos only from standard albums, '0' - to return all photos including those in service albums, e.g., 'My wall photos' (default)
        :param offset: Offset needed to return a specific subset of photos. By default, '0'.
        :param owner_id: ID of a user or community that owns the photos. Use a negative value to designate a community ID.
        :param photo_sizes: '1' - to return image sizes in [vk.com/dev/photo_sizes|special format].
        :param skip_hidden: '1' - not to return photos being hidden from the block above the wall. Works only with owner_id>0, no_service_albums is ignored.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("photos.getAll", params)
        model = PhotosGetAllResponse
        return model(**response).response

    async def get_all_comments(
        self,
        album_id: int | None = None,
        count: int | None = None,
        need_likes: bool | None = None,
        offset: int | None = None,
        owner_id: int | None = None,
        **kwargs: typing.Any,
    ) -> PhotosGetAllCommentsResponseModel:
        """Method `photos.getAllComments()`

        :param album_id: Album ID. If the parameter is not set, comments on all of the user's albums will be returned.
        :param count: Number of comments to return. By default, '20'. Maximum value, '100'.
        :param need_likes: '1' - to return an additional 'likes' field, '0' - (default)
        :param offset: Offset needed to return a specific subset of comments. By default, '0'.
        :param owner_id: ID of the user or community that owns the album(s).
        """

        params = self.get_set_params(locals())
        response = await self.api.request("photos.getAllComments", params)
        model = PhotosGetAllCommentsResponse
        return model(**response).response

    async def get_by_id(
        self,
        photos: list[str],
        extended: bool | None = None,
        photo_sizes: bool | None = None,
        **kwargs: typing.Any,
    ) -> list[PhotosPhoto]:
        """Method `photos.getById()`

        :param photos: IDs separated with a comma, that are IDs of users who posted photos and IDs of photos themselves with an underscore character between such IDs. To get information about a photo in the group album, you shall specify group ID instead of user ID. Example: "1_129207899,6492_135055734, , -20629724_271945303"
        :param extended: '1' - to return additional fields, '0' - (default)
        :param photo_sizes: '1' - to return photo sizes in a
        """

        params = self.get_set_params(locals())
        response = await self.api.request("photos.getById", params)
        model = PhotosGetByIdResponse
        return model(**response).response

    async def get_chat_upload_server(
        self,
        chat_id: int,
        crop_width: int | None = None,
        crop_x: int | None = None,
        crop_y: int | None = None,
        **kwargs: typing.Any,
    ) -> "BaseUploadServer":
        """Method `photos.getChatUploadServer()`

        :param chat_id: ID of the chat for which you want to upload a cover photo.
        :param crop_width: Width (in pixels) of the photo after cropping.
        :param crop_x:
        :param crop_y:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("photos.getChatUploadServer", params)
        model = BaseGetUploadServerResponse
        return model(**response).response

    @typing.overload
    async def get_comments(
        self,
        photo_id: int,
        extended: typing.Literal[True],
        access_key: str | None = None,
        count: int | None = None,
        fields: list[UsersFields] | None = None,
        need_likes: bool | None = None,
        offset: int | None = None,
        owner_id: int | None = None,
        sort: str | None = None,
        start_comment_id: int | None = None,
        **kwargs: typing.Any,
    ) -> PhotosGetCommentsExtendedResponseModel: ...

    @typing.overload
    async def get_comments(
        self,
        photo_id: int,
        extended: typing.Literal[False] | None = None,
        access_key: str | None = None,
        count: int | None = None,
        fields: list[UsersFields] | None = None,
        need_likes: bool | None = None,
        offset: int | None = None,
        owner_id: int | None = None,
        sort: str | None = None,
        start_comment_id: int | None = None,
        **kwargs: typing.Any,
    ) -> PhotosGetCommentsResponseModel: ...

    async def get_comments(
        self,
        photo_id: int,
        extended: bool | None = None,
        access_key: str | None = None,
        count: int | None = None,
        fields: list[UsersFields] | None = None,
        need_likes: bool | None = None,
        offset: int | None = None,
        owner_id: int | None = None,
        sort: str | None = None,
        start_comment_id: int | None = None,
        **kwargs: typing.Any,
    ) -> PhotosGetCommentsResponseModel | PhotosGetCommentsExtendedResponseModel:
        """Method `photos.getComments()`

        :param photo_id: Photo ID.
        :param extended:
        :param access_key:
        :param count: Number of comments to return.
        :param fields:
        :param need_likes: '1' - to return an additional 'likes' field, '0' - (default)
        :param offset: Offset needed to return a specific subset of comments. By default, '0'.
        :param owner_id: ID of the user or community that owns the photo.
        :param sort: Sort order: 'asc' - old first, 'desc' - new first
        :param start_comment_id:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("photos.getComments", params)
        model = self.get_model(
            ((("extended",), PhotosGetCommentsExtendedResponse),),
            default=PhotosGetCommentsResponse,
            params=params,
        )
        return model(**response).response

    async def get_market_album_upload_server(
        self,
        group_id: int,
        **kwargs: typing.Any,
    ) -> "BaseUploadServer":
        """Method `photos.getMarketAlbumUploadServer()`

        :param group_id: Community ID.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("photos.getMarketAlbumUploadServer", params)
        model = BaseGetUploadServerResponse
        return model(**response).response

    async def get_messages_upload_server(
        self,
        peer_id: int | None = None,
        **kwargs: typing.Any,
    ) -> "PhotosPhotoUpload":
        """Method `photos.getMessagesUploadServer()`

        :param peer_id: Destination ID. "For user: 'User ID', e.g. '12345'. For chat: '2000000000' + 'Chat ID', e.g. '2000000001'. For community: '- Community ID', e.g. '-12345'. "
        """

        params = self.get_set_params(locals())
        response = await self.api.request("photos.getMessagesUploadServer", params)
        model = PhotosGetMessagesUploadServerResponse
        return model(**response).response

    async def get_new_tags(
        self,
        count: int | None = None,
        offset: int | None = None,
        **kwargs: typing.Any,
    ) -> PhotosGetNewTagsResponseModel:
        """Method `photos.getNewTags()`

        :param count: Number of photos to return.
        :param offset: Offset needed to return a specific subset of photos.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("photos.getNewTags", params)
        model = PhotosGetNewTagsResponse
        return model(**response).response

    async def get_owner_cover_photo_upload_server(
        self,
        crop_x: int | None = None,
        crop_x2: int | None = None,
        crop_y: int | None = None,
        crop_y2: int | None = None,
        group_id: int | None = None,
        is_video_cover: bool | None = None,
        **kwargs: typing.Any,
    ) -> "BaseUploadServer":
        """Method `photos.getOwnerCoverPhotoUploadServer()`

        :param crop_x: X coordinate of the left-upper corner
        :param crop_x2: X coordinate of the right-bottom corner
        :param crop_y: Y coordinate of the left-upper corner
        :param crop_y2: Y coordinate of the right-bottom corner
        :param group_id: ID of community that owns the album (if the photo will be uploaded to a community album).
        :param is_video_cover:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("photos.getOwnerCoverPhotoUploadServer", params)
        model = BaseGetUploadServerResponse
        return model(**response).response

    async def get_owner_photo_upload_server(
        self,
        owner_id: int | None = None,
        **kwargs: typing.Any,
    ) -> "BaseUploadServer":
        """Method `photos.getOwnerPhotoUploadServer()`

        :param owner_id: identifier of a community or current user. "Note that community id must be negative. 'owner_id=1' - user, 'owner_id=-1' - community, "
        """

        params = self.get_set_params(locals())
        response = await self.api.request("photos.getOwnerPhotoUploadServer", params)
        model = BaseGetUploadServerResponse
        return model(**response).response

    async def get_tags(
        self,
        photo_id: int,
        access_key: str | None = None,
        owner_id: int | None = None,
        **kwargs: typing.Any,
    ) -> list[PhotosPhotoTag]:
        """Method `photos.getTags()`

        :param photo_id: Photo ID.
        :param access_key:
        :param owner_id: ID of the user or community that owns the photo.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("photos.getTags", params)
        model = PhotosGetTagsResponse
        return model(**response).response

    async def get_upload_server(
        self,
        album_id: int | None = None,
        group_id: int | None = None,
        **kwargs: typing.Any,
    ) -> "PhotosPhotoUpload":
        """Method `photos.getUploadServer()`

        :param album_id:
        :param group_id: ID of community that owns the album (if the photo will be uploaded to a community album).
        """

        params = self.get_set_params(locals())
        response = await self.api.request("photos.getUploadServer", params)
        model = PhotosGetUploadServerResponse
        return model(**response).response

    async def get_user_photos(
        self,
        count: int | None = None,
        extended: bool | None = None,
        offset: int | None = None,
        sort: str | None = None,
        user_id: int | None = None,
        **kwargs: typing.Any,
    ) -> PhotosGetUserPhotosResponseModel:
        """Method `photos.getUserPhotos()`

        :param count: Number of photos to return. Maximum value is 1000.
        :param extended: '1' - to return an additional 'likes' field, '0' - (default)
        :param offset: Offset needed to return a specific subset of photos. By default, '0'.
        :param sort: Sort order: '1' - by date the tag was added in ascending order, '0' - by date the tag was added in descending order
        :param user_id: User ID.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("photos.getUserPhotos", params)
        model = PhotosGetUserPhotosResponse
        return model(**response).response

    async def get_wall_upload_server(
        self,
        group_id: int | None = None,
        **kwargs: typing.Any,
    ) -> "PhotosPhotoUpload":
        """Method `photos.getWallUploadServer()`

        :param group_id: ID of community to whose wall the photo will be uploaded.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("photos.getWallUploadServer", params)
        model = PhotosGetWallUploadServerResponse
        return model(**response).response

    async def make_cover(
        self,
        photo_id: int,
        album_id: int | None = None,
        owner_id: int | None = None,
        **kwargs: typing.Any,
    ) -> BaseOkResponseModel:
        """Method `photos.makeCover()`

        :param photo_id: Photo ID.
        :param album_id: Album ID.
        :param owner_id: ID of the user or community that owns the photo.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("photos.makeCover", params)
        model = BaseOkResponse
        return model(**response).response

    async def move(
        self,
        photo_ids: list[int],
        target_album_id: int,
        owner_id: int | None = None,
        **kwargs: typing.Any,
    ) -> BaseOkResponseModel:
        """Method `photos.move()`

        :param photo_ids:
        :param target_album_id: ID of the album to which the photo will be moved.
        :param owner_id: ID of the user or community that owns the photo.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("photos.move", params)
        model = BaseOkResponse
        return model(**response).response

    async def put_tag(
        self,
        photo_id: int,
        user_id: int,
        owner_id: int | None = None,
        x: float | None = None,
        x2: float | None = None,
        y: float | None = None,
        y2: float | None = None,
        **kwargs: typing.Any,
    ) -> int:
        """Method `photos.putTag()`

        :param photo_id: Photo ID.
        :param user_id: ID of the user to be tagged.
        :param owner_id: ID of the user or community that owns the photo.
        :param x: Upper left-corner coordinate of the tagged area (as a percentage of the photo's width).
        :param x2: Lower right-corner coordinate of the tagged area (as a percentage of the photo's width).
        :param y: Upper left-corner coordinate of the tagged area (as a percentage of the photo's height).
        :param y2: Lower right-corner coordinate of the tagged area (as a percentage of the photo's height).
        """

        params = self.get_set_params(locals())
        response = await self.api.request("photos.putTag", params)
        model = PhotosPutTagResponse
        return model(**response).response

    async def remove_tag(
        self,
        photo_id: int,
        tag_id: int,
        owner_id: int | None = None,
        **kwargs: typing.Any,
    ) -> BaseOkResponseModel:
        """Method `photos.removeTag()`

        :param photo_id: Photo ID.
        :param tag_id: Tag ID.
        :param owner_id: ID of the user or community that owns the photo.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("photos.removeTag", params)
        model = BaseOkResponse
        return model(**response).response

    async def reorder_albums(
        self,
        album_id: int,
        after: int | None = None,
        before: int | None = None,
        owner_id: int | None = None,
        **kwargs: typing.Any,
    ) -> BaseOkResponseModel:
        """Method `photos.reorderAlbums()`

        :param album_id: Album ID.
        :param after: ID of the album after which the album in question shall be placed.
        :param before: ID of the album before which the album in question shall be placed.
        :param owner_id: ID of the user or community that owns the album.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("photos.reorderAlbums", params)
        model = BaseOkResponse
        return model(**response).response

    async def reorder_photos(
        self,
        photo_id: int,
        after: int | None = None,
        before: int | None = None,
        owner_id: int | None = None,
        **kwargs: typing.Any,
    ) -> BaseOkResponseModel:
        """Method `photos.reorderPhotos()`

        :param photo_id: Photo ID.
        :param after: ID of the photo after which the photo in question shall be placed.
        :param before: ID of the photo before which the photo in question shall be placed.
        :param owner_id: ID of the user or community that owns the photo.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("photos.reorderPhotos", params)
        model = BaseOkResponse
        return model(**response).response

    async def report(
        self,
        owner_id: int,
        photo_id: int,
        reason: int | None = None,
        **kwargs: typing.Any,
    ) -> BaseOkResponseModel:
        """Method `photos.report()`

        :param owner_id: ID of the user or community that owns the photo.
        :param photo_id: Photo ID.
        :param reason: Reason for the complaint: '0' - spam, '1' - child pornography, '2' - extremism, '3' - violence, '4' - drug propaganda, '5' - adult material, '6' - insult, abuse, '8' - suicide calls
        """

        params = self.get_set_params(locals())
        response = await self.api.request("photos.report", params)
        model = BaseOkResponse
        return model(**response).response

    async def report_comment(
        self,
        comment_id: int,
        owner_id: int,
        reason: int | None = None,
        **kwargs: typing.Any,
    ) -> BaseOkResponseModel:
        """Method `photos.reportComment()`

        :param comment_id: ID of the comment being reported.
        :param owner_id: ID of the user or community that owns the photo.
        :param reason: Reason for the complaint: '0' - spam, '1' - child pornography, '2' - extremism, '3' - violence, '4' - drug propaganda, '5' - adult material, '6' - insult, abuse
        """

        params = self.get_set_params(locals())
        response = await self.api.request("photos.reportComment", params)
        model = BaseOkResponse
        return model(**response).response

    async def restore(
        self,
        photo_id: int,
        owner_id: int | None = None,
        **kwargs: typing.Any,
    ) -> BaseOkResponseModel:
        """Method `photos.restore()`

        :param photo_id: Photo ID.
        :param owner_id: ID of the user or community that owns the photo.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("photos.restore", params)
        model = BaseOkResponse
        return model(**response).response

    async def restore_comment(
        self,
        comment_id: int,
        owner_id: int | None = None,
        **kwargs: typing.Any,
    ) -> bool:
        """Method `photos.restoreComment()`

        :param comment_id: ID of the deleted comment.
        :param owner_id: ID of the user or community that owns the photo.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("photos.restoreComment", params)
        model = BaseBoolResponse
        return model(**response).response

    async def save(
        self,
        album_id: int | None = None,
        caption: str | None = None,
        group_id: int | None = None,
        hash: str | None = None,
        latitude: float | None = None,
        longitude: float | None = None,
        photos_list: str | None = None,
        server: int | None = None,
        **kwargs: typing.Any,
    ) -> list[PhotosPhoto]:
        """Method `photos.save()`

        :param album_id: ID of the album to save photos to.
        :param caption: Text describing the photo. 2048 digits max.
        :param group_id: ID of the community to save photos to.
        :param hash: Parameter returned when photos are [vk.com/dev/upload_files|uploaded to server].
        :param latitude: Geographical latitude, in degrees (from '-90' to '90').
        :param longitude: Geographical longitude, in degrees (from '-180' to '180').
        :param photos_list: Parameter returned when photos are [vk.com/dev/upload_files|uploaded to server].
        :param server: Parameter returned when photos are [vk.com/dev/upload_files|uploaded to server].
        """

        params = self.get_set_params(locals())
        response = await self.api.request("photos.save", params)
        model = PhotosSaveResponse
        return model(**response).response

    async def save_market_album_photo(
        self,
        group_id: int,
        hash: str,
        photo: str,
        server: int,
        **kwargs: typing.Any,
    ) -> list[PhotosPhoto]:
        """Method `photos.saveMarketAlbumPhoto()`

        :param group_id: Community ID.
        :param hash: Parameter returned when photos are [vk.com/dev/upload_files|uploaded to server].
        :param photo: Parameter returned when photos are [vk.com/dev/upload_files|uploaded to server].
        :param server: Parameter returned when photos are [vk.com/dev/upload_files|uploaded to server].
        """

        params = self.get_set_params(locals())
        response = await self.api.request("photos.saveMarketAlbumPhoto", params)
        model = PhotosSaveMarketAlbumPhotoResponse
        return model(**response).response

    async def save_messages_photo(
        self,
        photo: str,
        hash: str | None = None,
        server: int | None = None,
        **kwargs: typing.Any,
    ) -> list[PhotosPhoto]:
        """Method `photos.saveMessagesPhoto()`

        :param photo: Parameter returned when the photo is [vk.com/dev/upload_files|uploaded to the server].
        :param hash:
        :param server:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("photos.saveMessagesPhoto", params)
        model = PhotosSaveMessagesPhotoResponse
        return model(**response).response

    async def save_owner_cover_photo(
        self,
        crop_height: int | None = None,
        crop_width: int | None = None,
        crop_x: int | None = None,
        crop_y: int | None = None,
        hash: str | None = None,
        is_video_cover: bool | None = None,
        photo: str | None = None,
        response_json: str | None = None,
        **kwargs: typing.Any,
    ) -> PhotosSaveOwnerCoverPhotoResponseModel:
        """Method `photos.saveOwnerCoverPhoto()`

        :param crop_height:
        :param crop_width:
        :param crop_x:
        :param crop_y:
        :param hash: Parameter returned when photos are [vk.com/dev/upload_files|uploaded to server].
        :param is_video_cover:
        :param photo: Parameter returned when photos are [vk.com/dev/upload_files|uploaded to server].
        :param response_json:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("photos.saveOwnerCoverPhoto", params)
        model = PhotosSaveOwnerCoverPhotoResponse
        return model(**response).response

    async def save_owner_photo(
        self,
        hash: str | None = None,
        photo: str | None = None,
        server: str | None = None,
        **kwargs: typing.Any,
    ) -> PhotosSaveOwnerPhotoResponseModel:
        """Method `photos.saveOwnerPhoto()`

        :param hash: parameter returned after [vk.com/dev/upload_files|photo upload].
        :param photo: parameter returned after [vk.com/dev/upload_files|photo upload].
        :param server: parameter returned after [vk.com/dev/upload_files|photo upload].
        """

        params = self.get_set_params(locals())
        response = await self.api.request("photos.saveOwnerPhoto", params)
        model = PhotosSaveOwnerPhotoResponse
        return model(**response).response

    async def save_wall_photo(
        self,
        photo: str,
        caption: str | None = None,
        group_id: int | None = None,
        hash: str | None = None,
        latitude: float | None = None,
        longitude: float | None = None,
        server: int | None = None,
        user_id: int | None = None,
        **kwargs: typing.Any,
    ) -> list[PhotosPhoto]:
        """Method `photos.saveWallPhoto()`

        :param photo: Parameter returned when the the photo is [vk.com/dev/upload_files|uploaded to the server].
        :param caption: Text describing the photo. 2048 digits max.
        :param group_id: ID of community on whose wall the photo will be saved.
        :param hash:
        :param latitude: Geographical latitude, in degrees (from '-90' to '90').
        :param longitude: Geographical longitude, in degrees (from '-180' to '180').
        :param server:
        :param user_id: ID of the user on whose wall the photo will be saved.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("photos.saveWallPhoto", params)
        model = PhotosSaveWallPhotoResponse
        return model(**response).response

    async def search(
        self,
        count: int | None = None,
        end_time: float | None = None,
        lat: float | None = None,
        long: float | None = None,
        offset: int | None = None,
        q: str | None = None,
        radius: int | None = None,
        sort: int | None = None,
        start_time: float | None = None,
        **kwargs: typing.Any,
    ) -> PhotosSearchResponseModel:
        """Method `photos.search()`

        :param count: Number of photos to return.
        :param end_time:
        :param lat: Geographical latitude, in degrees (from '-90' to '90').
        :param long: Geographical longitude, in degrees (from '-180' to '180').
        :param offset: Offset needed to return a specific subset of photos.
        :param q: Search query string.
        :param radius: Radius of search in meters (works very approximately). Available values: '10', '100', '800', '6000', '50000'.
        :param sort: Sort order:
        :param start_time:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("photos.search", params)
        model = PhotosSearchResponse
        return model(**response).response


__all__ = ("PhotosCategory",)



from vkbottle_types.base_model import BaseModel, Field
from vkbottle_types.objects import LeadFormsForm, LeadFormsLead
from vkbottle_types.responses.base_response import BaseResponse


class LeadFormsCreateResponseModel(BaseModel):
    form_id: int = Field()
    url: str = Field()


class LeadFormsCreateResponse(BaseResponse):
    response: "LeadFormsCreateResponseModel" = Field()


class LeadFormsDeleteResponseModel(BaseModel):
    form_id: int = Field()


class LeadFormsDeleteResponse(BaseResponse):
    response: "LeadFormsDeleteResponseModel" = Field()


class LeadFormsGetLeadsResponseModel(BaseModel):
    leads: list["LeadFormsLead"] = Field()
    next_page_token: str | None = Field(
        default=None,
    )


class LeadFormsGetLeadsResponse(BaseResponse):
    response: "LeadFormsGetLeadsResponseModel" = Field()


class LeadFormsGetResponse(BaseResponse):
    response: "LeadFormsForm" = Field()


class LeadFormsListResponse(BaseResponse):
    response: list["LeadFormsForm"] = Field()


class LeadFormsUploadUrlResponse(BaseResponse):
    response: str = Field()



from vkbottle_types.base_model import BaseModel, Field
from vkbottle_types.objects import DonutDonatorSubscriptionInfo, GroupsGroupFull, UsersUserFull
from vkbottle_types.responses.base_response import BaseResponse


class DonutGetSubscriptionResponse(BaseResponse):
    response: "DonutDonatorSubscriptionInfo" = Field()


class DonutGetSubscriptionsResponseModel(BaseModel):
    subscriptions: list["DonutDonatorSubscriptionInfo"] = Field()
    count: int | None = Field(
        default=None,
    )
    profiles: list["UsersUserFull"] | None = Field(
        default=None,
    )
    groups: list["GroupsGroupFull"] | None = Field(
        default=None,
    )


class DonutGetSubscriptionsResponse(BaseResponse):
    response: "DonutGetSubscriptionsResponseModel" = Field()



from vkbottle_types.base_model import BaseModel, Field
from vkbottle_types.objects import (
    GroupsGroupFull,
    MarketGlobalSearchFilters,
    MarketMarketAlbum,
    MarketMarketCategoryTree,
    MarketMarketItem,
    MarketMarketItemBasicWithGroup,
    MarketMarketItemFull,
    MarketOrder,
    MarketOrderItem,
    MarketProperty,
    MarketServicesViewType,
    MarketUploadPhotoData,
    PhotosPhoto,
    UsersUserFull,
    WallWallComment,
)
from vkbottle_types.responses.base_response import BaseResponse


class MarketAddAlbumResponseModel(BaseModel):
    market_album_id: int | None = Field(
        default=None,
    )
    albums_count: int | None = Field(
        default=None,
    )


class MarketAddAlbumResponse(BaseResponse):
    response: "MarketAddAlbumResponseModel" = Field()


class MarketAddPropertyVariantResponseModel(BaseModel):
    variant_id: int = Field()


class MarketAddPropertyVariantResponse(BaseResponse):
    response: "MarketAddPropertyVariantResponseModel" = Field()


class MarketAddPropertyResponseModel(BaseModel):
    property_id: int = Field()


class MarketAddPropertyResponse(BaseResponse):
    response: "MarketAddPropertyResponseModel" = Field()


class MarketAddResponseModel(BaseModel):
    market_item_id: int = Field()


class MarketAddResponse(BaseResponse):
    response: "MarketAddResponseModel" = Field()


class MarketCreateCommentResponse(BaseResponse):
    response: int = Field()


class MarketGetAlbumByIdResponseModel(BaseModel):
    count: int = Field()
    items: list["MarketMarketAlbum"] = Field()


class MarketGetAlbumByIdResponse(BaseResponse):
    response: "MarketGetAlbumByIdResponseModel" = Field()


class MarketGetAlbumsResponseModel(BaseModel):
    count: int = Field()
    items: list["MarketMarketAlbum"] = Field()


class MarketGetAlbumsResponse(BaseResponse):
    response: "MarketGetAlbumsResponseModel" = Field()


class MarketGetByIdExtendedResponseModel(BaseModel):
    count: int = Field()
    items: list["MarketMarketItemFull"] = Field()


class MarketGetByIdExtendedResponse(BaseResponse):
    response: "MarketGetByIdExtendedResponseModel" = Field()


class MarketGetByIdResponseModel(BaseModel):
    count: int = Field()
    items: list["MarketMarketItem"] = Field()


class MarketGetByIdResponse(BaseResponse):
    response: "MarketGetByIdResponseModel" = Field()


class MarketGetCategoriesNewResponseModel(BaseModel):
    items: list["MarketMarketCategoryTree"] = Field()


class MarketGetCategoriesNewResponse(BaseResponse):
    response: "MarketGetCategoriesNewResponseModel" = Field()


class MarketGetCommentsResponseModel(BaseModel):
    count: int = Field()
    items: list["WallWallComment"] = Field()
    profiles: list["UsersUserFull"] | None = Field(
        default=None,
    )
    groups: list["GroupsGroupFull"] | None = Field(
        default=None,
    )


class MarketGetCommentsResponse(BaseResponse):
    response: "MarketGetCommentsResponseModel" = Field()


class MarketGetFavesForAttachResponseModel(BaseModel):
    market_items: list["MarketMarketItem"] = Field()
    next_from: int | None = Field(
        default=None,
    )


class MarketGetFavesForAttachResponse(BaseResponse):
    response: "MarketGetFavesForAttachResponseModel" = Field()


class MarketGetGroupOrdersResponseModel(BaseModel):
    count: int = Field()
    items: list["MarketOrder"] = Field()


class MarketGetGroupOrdersResponse(BaseResponse):
    response: "MarketGetGroupOrdersResponseModel" = Field()


class MarketGetOrderByIdResponseModel(BaseModel):
    order: "MarketOrder | None" = Field(
        default=None,
    )


class MarketGetOrderByIdResponse(BaseResponse):
    response: "MarketGetOrderByIdResponseModel" = Field()


class MarketGetOrderItemsResponseModel(BaseModel):
    count: int = Field()
    items: list["MarketOrderItem"] = Field()


class MarketGetOrderItemsResponse(BaseResponse):
    response: "MarketGetOrderItemsResponseModel" = Field()


class MarketGetOrdersExtendedResponseModel(BaseModel):
    count: int = Field()
    items: list["MarketOrder"] = Field()
    groups: list["GroupsGroupFull"] | None = Field(
        default=None,
    )


class MarketGetOrdersExtendedResponse(BaseResponse):
    response: "MarketGetOrdersExtendedResponseModel" = Field()


class MarketGetOrdersResponseModel(BaseModel):
    count: int = Field()
    items: list["MarketOrder"] = Field()


class MarketGetOrdersResponse(BaseResponse):
    response: "MarketGetOrdersResponseModel" = Field()


class MarketGetPropertiesResponseModel(BaseModel):
    items: list["MarketProperty"] = Field()
    count: int = Field()


class MarketGetPropertiesResponse(BaseResponse):
    response: "MarketGetPropertiesResponseModel" = Field()


class MarketGetExtendedResponseModel(BaseModel):
    count: int = Field()
    items: list["MarketMarketItemFull"] = Field()
    variants: list["MarketMarketItemFull"] | None = Field(
        default=None,
    )


class MarketGetExtendedResponse(BaseResponse):
    response: "MarketGetExtendedResponseModel" = Field()


class MarketGetResponseModel(BaseModel):
    count: int = Field()
    items: list["MarketMarketItem"] = Field()
    variants: list["MarketMarketItem"] | None = Field(
        default=None,
    )


class MarketGetResponse(BaseResponse):
    response: "MarketGetResponseModel" = Field()


class MarketGroupItemsResponseModel(BaseModel):
    item_group_id: int = Field()


class MarketGroupItemsResponse(BaseResponse):
    response: "MarketGroupItemsResponseModel" = Field()


class MarketPhotoIdBulkResponse(BaseResponse):
    response: list["MarketUploadPhotoData"] = Field()


class MarketPhotoIdResponseModel(BaseModel):
    photo_id: int = Field()
    photo: "PhotosPhoto | None" = Field(
        default=None,
    )


class MarketPhotoIdResponse(BaseResponse):
    response: "MarketPhotoIdResponseModel" = Field()


class MarketSearchBasicResponseModel(BaseModel):
    count: int = Field()
    total: int = Field()
    items: list["MarketMarketItemBasicWithGroup"] = Field()
    has_more: bool | None = Field(
        default=None,
    )


class MarketSearchBasicResponse(BaseResponse):
    response: "MarketSearchBasicResponseModel" = Field()


class MarketSearchExtendedResponseModel(BaseModel):
    count: int = Field()
    view_type: "MarketServicesViewType" = Field()
    items: list["MarketMarketItemFull"] = Field()
    variants: list["MarketMarketItemFull"] | None = Field(
        default=None,
    )


class MarketSearchExtendedResponse(BaseResponse):
    response: "MarketSearchExtendedResponseModel" = Field()


class MarketSearchResponseModel(BaseModel):
    count: int = Field()
    view_type: "MarketServicesViewType" = Field()
    items: list["MarketMarketItem"] = Field()
    variants: list["MarketMarketItem"] | None = Field(
        default=None,
    )
    groups: list["GroupsGroupFull"] | None = Field(
        default=None,
    )
    filters: "MarketGlobalSearchFilters | None" = Field(
        default=None,
    )


class MarketSearchResponse(BaseResponse):
    response: "MarketSearchResponseModel" = Field()



from vkbottle_types.base_model import BaseModel, Field
from vkbottle_types.objects import (
    GroupsGroupFull,
    NewsfeedCommentsItem,
    NewsfeedList,
    NewsfeedListFull,
    NewsfeedNewsfeedItem,
    UsersSubscriptionsItem,
    UsersUserFull,
    WallWallpostFull,
)
from vkbottle_types.responses.base_response import BaseResponse


class NewsfeedGenericResponseModel(BaseModel):
    items: list["NewsfeedNewsfeedItem"] = Field()
    profiles: list["UsersUserFull"] = Field()
    groups: list["GroupsGroupFull"] = Field()
    lives_items: list["NewsfeedNewsfeedItem"] | None = Field(
        default=None,
    )


class NewsfeedGenericResponse(BaseResponse):
    response: "NewsfeedGenericResponseModel" = Field()


class NewsfeedGetBannedExtendedResponseModel(BaseModel):
    profiles: list["UsersUserFull"] | None = Field(
        default=None,
    )
    groups: list["GroupsGroupFull"] | None = Field(
        default=None,
    )


class NewsfeedGetBannedExtendedResponse(BaseResponse):
    response: "NewsfeedGetBannedExtendedResponseModel" = Field()


class NewsfeedGetBannedResponseModel(BaseModel):
    groups: list[int] | None = Field(
        default=None,
    )
    members: list[int] | None = Field(
        default=None,
    )


class NewsfeedGetBannedResponse(BaseResponse):
    response: "NewsfeedGetBannedResponseModel" = Field()


class NewsfeedGetCommentsResponseModel(BaseModel):
    items: list["NewsfeedCommentsItem"] = Field()
    profiles: list["UsersUserFull"] = Field()
    groups: list["GroupsGroupFull"] = Field()
    next_from: str | None = Field(
        default=None,
    )


class NewsfeedGetCommentsResponse(BaseResponse):
    response: "NewsfeedGetCommentsResponseModel" = Field()


class NewsfeedGetListsExtendedResponseModel(BaseModel):
    count: int = Field()
    items: list["NewsfeedListFull"] = Field()


class NewsfeedGetListsExtendedResponse(BaseResponse):
    response: "NewsfeedGetListsExtendedResponseModel" = Field()


class NewsfeedGetListsResponseModel(BaseModel):
    count: int = Field()
    items: list["NewsfeedList"] = Field()


class NewsfeedGetListsResponse(BaseResponse):
    response: "NewsfeedGetListsResponseModel" = Field()


class NewsfeedGetMentionsResponseModel(BaseModel):
    count: int = Field()
    items: list["WallWallpostFull"] = Field()


class NewsfeedGetMentionsResponse(BaseResponse):
    response: "NewsfeedGetMentionsResponseModel" = Field()


class NewsfeedGetSuggestedSourcesResponseModel(BaseModel):
    count: int = Field()
    items: list["UsersSubscriptionsItem"] = Field()


class NewsfeedGetSuggestedSourcesResponse(BaseResponse):
    response: "NewsfeedGetSuggestedSourcesResponseModel" = Field()


class NewsfeedIgnoreItemResponseModel(BaseModel):
    status: bool = Field(default=1)


class NewsfeedIgnoreItemResponse(BaseResponse):
    response: "NewsfeedIgnoreItemResponseModel" = Field()


class NewsfeedSaveListResponse(BaseResponse):
    response: int = Field()


class NewsfeedSearchExtendedResponseModel(BaseModel):
    items: list["WallWallpostFull"] = Field()
    count: int = Field()
    profiles: list["UsersUserFull"] | None = Field(
        default=None,
    )
    groups: list["GroupsGroupFull"] | None = Field(
        default=None,
    )
    suggested_queries: list[str] | None = Field(
        default=None,
    )
    next_from: str | None = Field(
        default=None,
    )
    total_count: int | None = Field(
        default=None,
    )


class NewsfeedSearchExtendedResponse(BaseResponse):
    response: "NewsfeedSearchExtendedResponseModel" = Field()


class NewsfeedSearchExtendedStrictResponseModel(BaseModel):
    items: list["WallWallpostFull"] = Field()
    count: int = Field()
    profiles: list["UsersUserFull"] | None = Field(
        default=None,
    )
    groups: list["GroupsGroupFull"] | None = Field(
        default=None,
    )
    suggested_queries: list[str] | None = Field(
        default=None,
    )
    next_from: str | None = Field(
        default=None,
    )
    total_count: int | None = Field(
        default=None,
    )


class NewsfeedSearchExtendedStrictResponse(BaseResponse):
    response: "NewsfeedSearchExtendedStrictResponseModel" = Field()


class NewsfeedSearchResponseModel(BaseModel):
    items: list["WallWallpostFull"] = Field()
    count: int = Field()
    suggested_queries: list[str] | None = Field(
        default=None,
    )
    next_from: str | None = Field(
        default=None,
    )
    total_count: int | None = Field(
        default=None,
    )


class NewsfeedSearchResponse(BaseResponse):
    response: "NewsfeedSearchResponseModel" = Field()


class NewsfeedSearchStrictResponseModel(BaseModel):
    items: list["WallWallpostFull"] = Field()
    count: int = Field()
    suggested_queries: list[str] | None = Field(
        default=None,
    )
    next_from: str | None = Field(
        default=None,
    )
    total_count: int | None = Field(
        default=None,
    )


class NewsfeedSearchStrictResponse(BaseResponse):
    response: "NewsfeedSearchStrictResponseModel" = Field()



from vkbottle_types.base_model import BaseModel, Field
from vkbottle_types.objects import (
    AppsApp,
    GroupsGroup,
    NotificationsNotificationItem,
    NotificationsSendMessageItem,
    PhotosPhoto,
    UsersUser,
    VideoVideoFull,
)
from vkbottle_types.responses.base_response import BaseResponse


class NotificationsGetResponseModel(BaseModel):
    count: int = Field()
    items: list["NotificationsNotificationItem"] = Field()
    profiles: list["UsersUser"] | None = Field(
        default=None,
    )
    groups: list["GroupsGroup"] | None = Field(
        default=None,
    )
    last_viewed: int | None = Field(
        default=None,
    )
    photos: list["PhotosPhoto"] | None = Field(
        default=None,
    )
    videos: list["VideoVideoFull"] | None = Field(
        default=None,
    )
    apps: list["AppsApp"] | None = Field(
        default=None,
    )
    next_from: str | None = Field(
        default=None,
    )
    ttl: int | None = Field(
        default=None,
    )


class NotificationsGetResponse(BaseResponse):
    response: "NotificationsGetResponseModel" = Field()


class NotificationsSendMessageResponse(BaseResponse):
    response: list["NotificationsSendMessageItem"] = Field()
